package android.content.res;

import android.content.Context;
import android.content.pm.PackageParser;
import android.content.res.Resources;
import android.graphics.Movie;
import android.graphics.Typeface;
import android.graphics.drawable.ColorDrawable;
import android.graphics.drawable.Drawable;
import android.os.StrictMode;
import android.util.AttributeSet;
import android.util.DisplayMetrics;
import android.util.SparseArray;
import android.util.TypedValue;
import android.view.LayoutInflater;
import android.view.View;
import android.view.ViewGroup;
import de.robv.android.xposed.XC_MethodHook;
import de.robv.android.xposed.XposedBridge;
import de.robv.android.xposed.XposedHelpers;
import de.robv.android.xposed.XposedInit;
import de.robv.android.xposed.callbacks.XC_LayoutInflated;
import de.robv.android.xposed.callbacks.XCallback;
import java.io.File;
import java.util.Arrays;
import java.util.HashMap;
import java.util.LinkedList;
import java.util.Objects;
import java.util.WeakHashMap;
import org.lsposed.lspd.nativebridge.ResourcesHook;
import org.xmlpull.v1.XmlPullParser;
import pxb.android.ResConst;
import xposed.dummy.XResourcesSuperClass;
import xposed.dummy.XTypedArraySuperClass;

public class XResources extends XResourcesSuperClass {
    private static final String EXTRA_XML_INSTANCE_DETAILS = "xmlInstanceDetails";
    private static final SparseArray<ColorStateList> sColorStateListCache = new SparseArray<>(0);
    private static final ThreadLocal<LinkedList<XC_MethodHook.MethodHookParam>> sIncludedLayouts = new ThreadLocal<LinkedList<XC_MethodHook.MethodHookParam>>() {
        /* class android.content.res.XResources.AnonymousClass1 */

        /* access modifiers changed from: protected */
        @Override // java.lang.ThreadLocal
        public LinkedList<XC_MethodHook.MethodHookParam> initialValue() {
            return new LinkedList<>();
        }
    };
    private static ThreadLocal<Object> sLatestResKey = null;
    private static final SparseArray<HashMap<String, XposedBridge.CopyOnWriteSortedSet<XC_LayoutInflated>>> sLayoutCallbacks = new SparseArray<>();
    private static final SparseArray<HashMap<String, Object>> sReplacements = new SparseArray<>();
    private static final HashMap<String, byte[]> sReplacementsCacheMap = new HashMap<>();
    private static final HashMap<String, Long> sResDirLastModified = new HashMap<>();
    private static final HashMap<String, String> sResDirPackageNames = new HashMap<>();
    private static final SparseArray<HashMap<String, ResourceNames>> sResourceNames = new SparseArray<>();
    private static final byte[] sSystemReplacementsCache = new byte[ResConst.RES_XML_START_NAMESPACE_TYPE];
    private static final WeakHashMap<XmlResourceParser, XMLInstanceDetails> sXmlInstanceDetails = new WeakHashMap<>();
    private boolean mIsObjectInited;
    private String mPackageName;
    private byte[] mReplacementsCache;
    private String mResDir;

    static /* synthetic */ byte[] lambda$initObject$0(String str) {
        return new byte[128];
    }

    public XResources(ClassLoader classLoader) {
        super(classLoader);
    }

    public void initObject(String str) {
        if (!this.mIsObjectInited) {
            this.mResDir = str;
            this.mPackageName = getPackageName(str);
            if (str != null) {
                HashMap<String, byte[]> hashMap = sReplacementsCacheMap;
                synchronized (hashMap) {
                    this.mReplacementsCache = hashMap.computeIfAbsent(str, new XResources$$ExternalSyntheticLambda0());
                }
            }
            this.mIsObjectInited = true;
            return;
        }
        throw new IllegalStateException("Object has already been initialized");
    }

    public boolean isFirstLoad() {
        synchronized (sReplacements) {
            if (this.mResDir == null) {
                return false;
            }
            StrictMode.ThreadPolicy allowThreadDiskReads = StrictMode.allowThreadDiskReads();
            Long valueOf = Long.valueOf(new File(this.mResDir).lastModified());
            HashMap<String, Long> hashMap = sResDirLastModified;
            Long l = hashMap.get(this.mResDir);
            StrictMode.setThreadPolicy(allowThreadDiskReads);
            if (valueOf.equals(l)) {
                return false;
            }
            hashMap.put(this.mResDir, valueOf);
            if (l == null) {
                return true;
            }
            int i = 0;
            while (true) {
                SparseArray<HashMap<String, Object>> sparseArray = sReplacements;
                if (i < sparseArray.size()) {
                    sparseArray.valueAt(i).remove(this.mResDir);
                    i++;
                } else {
                    Arrays.fill(this.mReplacementsCache, (byte) 0);
                    return true;
                }
            }
        }
    }

    public static void setPackageNameForResDir(String str, String str2) {
        HashMap<String, String> hashMap = sResDirPackageNames;
        synchronized (hashMap) {
            hashMap.put(str2, str);
        }
    }

    public String getPackageName() {
        return this.mPackageName;
    }

    private static String getPackageName(String str) {
        String str2;
        if (str == null) {
            return "android";
        }
        HashMap<String, String> hashMap = sResDirPackageNames;
        synchronized (hashMap) {
            str2 = hashMap.get(str);
        }
        if (str2 != null) {
            return str2;
        }
        try {
            PackageParser.PackageLite parsePackageLite = PackageParser.parsePackageLite(new File(str), 0);
            if (parsePackageLite == null || parsePackageLite.packageName == null) {
                throw new IllegalStateException("Could not determine package name for " + str);
            }
            String str3 = parsePackageLite.packageName;
            setPackageNameForResDir(str3, str);
            return str3;
        } catch (PackageParser.PackageParserException e) {
            throw new IllegalStateException("Could not determine package name for " + str, e);
        }
    }

    public static String getPackageNameDuringConstruction() {
        Object obj;
        ThreadLocal<Object> threadLocal = sLatestResKey;
        if (threadLocal != null && (obj = threadLocal.get()) != null) {
            return getPackageName((String) XposedHelpers.getObjectField(obj, "mResDir"));
        }
        throw new IllegalStateException("This method can only be called during getTopLevelResources()");
    }

    public static void init(ThreadLocal<Object> threadLocal) throws Exception {
        sLatestResKey = threadLocal;
        XposedHelpers.findAndHookMethod(LayoutInflater.class, "inflate", XmlPullParser.class, ViewGroup.class, Boolean.TYPE, new XC_MethodHook() {
            /* class android.content.res.XResources.AnonymousClass2 */

            /* access modifiers changed from: protected */
            @Override // de.robv.android.xposed.XC_MethodHook
            public void afterHookedMethod(XC_MethodHook.MethodHookParam methodHookParam) throws Throwable {
                XMLInstanceDetails xMLInstanceDetails;
                if (!methodHookParam.hasThrowable()) {
                    synchronized (XResources.sXmlInstanceDetails) {
                        xMLInstanceDetails = (XMLInstanceDetails) XResources.sXmlInstanceDetails.get(methodHookParam.args[0]);
                    }
                    if (xMLInstanceDetails != null) {
                        XC_LayoutInflated.LayoutInflatedParam layoutInflatedParam = new XC_LayoutInflated.LayoutInflatedParam(xMLInstanceDetails.callbacks);
                        layoutInflatedParam.view = (View) methodHookParam.getResult();
                        layoutInflatedParam.resNames = xMLInstanceDetails.resNames;
                        layoutInflatedParam.variant = xMLInstanceDetails.variant;
                        layoutInflatedParam.res = xMLInstanceDetails.res;
                        XCallback.callAll(layoutInflatedParam);
                    }
                }
            }
        });
        XposedHelpers.findAndHookMethod(LayoutInflater.class, "parseInclude", XmlPullParser.class, Context.class, View.class, AttributeSet.class, new XC_MethodHook() {
            /* class android.content.res.XResources.AnonymousClass3 */

            /* access modifiers changed from: protected */
            @Override // de.robv.android.xposed.XC_MethodHook
            public void beforeHookedMethod(XC_MethodHook.MethodHookParam methodHookParam) throws Throwable {
                ((LinkedList) XResources.sIncludedLayouts.get()).push(methodHookParam);
            }

            /* access modifiers changed from: protected */
            @Override // de.robv.android.xposed.XC_MethodHook
            public void afterHookedMethod(XC_MethodHook.MethodHookParam methodHookParam) throws Throwable {
                XMLInstanceDetails xMLInstanceDetails;
                ((LinkedList) XResources.sIncludedLayouts.get()).pop();
                if (!methodHookParam.hasThrowable() && (xMLInstanceDetails = (XMLInstanceDetails) methodHookParam.getObjectExtra(XResources.EXTRA_XML_INSTANCE_DETAILS)) != null) {
                    XC_LayoutInflated.LayoutInflatedParam layoutInflatedParam = new XC_LayoutInflated.LayoutInflatedParam(xMLInstanceDetails.callbacks);
                    ViewGroup viewGroup = (ViewGroup) methodHookParam.args[2];
                    layoutInflatedParam.view = viewGroup.getChildAt(viewGroup.getChildCount() - 1);
                    layoutInflatedParam.resNames = xMLInstanceDetails.resNames;
                    layoutInflatedParam.variant = xMLInstanceDetails.variant;
                    layoutInflatedParam.res = xMLInstanceDetails.res;
                    XCallback.callAll(layoutInflatedParam);
                }
            }
        });
    }

    public static class ResourceNames {
        public final String fullName;
        public final int id;
        public final String name;
        public final String pkg;
        public final String type;

        private ResourceNames(int i, String str, String str2, String str3) {
            this.id = i;
            this.pkg = str;
            this.name = str2;
            this.type = str3;
            this.fullName = str + ":" + str3 + "/" + str2;
        }

        public boolean equals(String str, String str2, String str3, int i) {
            return (str == null || str.equals(this.pkg)) && (str2 == null || str2.equals(this.name)) && ((str3 == null || str3.equals(this.type)) && (i == 0 || i == this.id));
        }
    }

    private ResourceNames getResourceNames(int i) {
        return new ResourceNames(i, getResourcePackageName(i), getResourceTypeName(i), getResourceEntryName(i));
    }

    private static ResourceNames getSystemResourceNames(int i) {
        Resources system = getSystem();
        return new ResourceNames(i, system.getResourcePackageName(i), system.getResourceTypeName(i), system.getResourceEntryName(i));
    }

    private static void putResourceNames(String str, ResourceNames resourceNames) {
        int i = resourceNames.id;
        SparseArray<HashMap<String, ResourceNames>> sparseArray = sResourceNames;
        synchronized (sparseArray) {
            HashMap<String, ResourceNames> hashMap = sparseArray.get(i);
            if (hashMap == null) {
                hashMap = new HashMap<>();
                sparseArray.put(i, hashMap);
            }
            synchronized (hashMap) {
                hashMap.put(str, resourceNames);
            }
        }
    }

    public void setReplacement(int i, Object obj) {
        setReplacement(i, obj, this);
    }

    @Deprecated
    public void setReplacement(String str, Object obj) {
        int identifier = getIdentifier(str, null, null);
        if (identifier != 0) {
            setReplacement(identifier, obj, this);
            return;
        }
        throw new Resources.NotFoundException(str);
    }

    public void setReplacement(String str, String str2, String str3, Object obj) {
        int identifier = getIdentifier(str3, str2, str);
        if (identifier != 0) {
            setReplacement(identifier, obj, this);
            return;
        }
        throw new Resources.NotFoundException(str + ":" + str2 + "/" + str3);
    }

    public static void setSystemWideReplacement(int i, Object obj) {
        setReplacement(i, obj, null);
    }

    @Deprecated
    public static void setSystemWideReplacement(String str, Object obj) {
        int identifier = getSystem().getIdentifier(str, null, null);
        if (identifier != 0) {
            setReplacement(identifier, obj, null);
            return;
        }
        throw new Resources.NotFoundException(str);
    }

    public static void setSystemWideReplacement(String str, String str2, String str3, Object obj) {
        int identifier = getSystem().getIdentifier(str3, str2, str);
        if (identifier != 0) {
            setReplacement(identifier, obj, null);
            return;
        }
        throw new Resources.NotFoundException(str + ":" + str2 + "/" + str3);
    }

    private static void setReplacement(int i, Object obj, XResources xResources) {
        String str = xResources != null ? xResources.mResDir : null;
        if (xResources == null) {
            try {
                XposedInit.hookResources();
            } catch (Throwable unused) {
                throw new IllegalStateException("Failed to initialize resources hook");
            }
        }
        if (i == 0) {
            throw new IllegalArgumentException("id 0 is not an allowed resource identifier");
        } else if (str == null && i >= 2130706432) {
            throw new IllegalArgumentException("ids >= 0x7f000000 are app specific and cannot be set for the framework");
        } else if (!(obj instanceof Drawable)) {
            if (i < 2130706432) {
                int i2 = ((i & 458752) >> 11) | ((i & 248) >> 3);
                byte[] bArr = sSystemReplacementsCache;
                synchronized (bArr) {
                    bArr[i2] = (byte) ((1 << (i & 7)) | bArr[i2]);
                }
            } else {
                int i3 = ((i & 458752) >> 12) | ((i & 120) >> 3);
                synchronized (xResources.mReplacementsCache) {
                    byte[] bArr2 = xResources.mReplacementsCache;
                    bArr2[i3] = (byte) ((1 << (i & 7)) | bArr2[i3]);
                }
            }
            SparseArray<HashMap<String, Object>> sparseArray = sReplacements;
            synchronized (sparseArray) {
                HashMap<String, Object> hashMap = sparseArray.get(i);
                if (hashMap == null) {
                    hashMap = new HashMap<>();
                    sparseArray.put(i, hashMap);
                }
                hashMap.put(str, obj);
            }
        } else {
            throw new IllegalArgumentException("Drawable replacements are deprecated since Xposed 2.1. Use DrawableLoader instead.");
        }
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private Object getReplacement(int i) {
        HashMap<String, Object> hashMap;
        if (i <= 0) {
            return null;
        }
        if (i < 2130706432) {
            if ((sSystemReplacementsCache[((i & 458752) >> 11) | ((i & 248) >> 3)] & (1 << (i & 7))) == 0) {
                return null;
            }
        } else if (this.mResDir != null) {
            if ((this.mReplacementsCache[((i & 458752) >> 12) | ((i & 120) >> 3)] & (1 << (i & 7))) == 0) {
                return null;
            }
        }
        SparseArray<HashMap<String, Object>> sparseArray = sReplacements;
        synchronized (sparseArray) {
            hashMap = sparseArray.get(i);
        }
        if (hashMap == null) {
            return null;
        }
        synchronized (hashMap) {
            Object obj = hashMap.get(this.mResDir);
            if (obj == null) {
                if (this.mResDir != null) {
                    return hashMap.get(null);
                }
            }
            return obj;
        }
    }

    public XmlResourceParser getAnimation(int i) throws Resources.NotFoundException {
        Object replacement = getReplacement(i);
        if (!(replacement instanceof XResForwarder)) {
            return XResources.super.getAnimation(i);
        }
        XResForwarder xResForwarder = (XResForwarder) replacement;
        Resources resources = xResForwarder.getResources();
        int id = xResForwarder.getId();
        boolean isXmlCached = isXmlCached(resources, id);
        XmlResourceParser animation = resources.getAnimation(id);
        if (!isXmlCached) {
            ResourcesHook.rewriteXmlReferencesNative(XposedHelpers.getLongField(animation, "mParseState"), this, resources);
        }
        return animation;
    }

    public boolean getBoolean(int i) throws Resources.NotFoundException {
        Object replacement = getReplacement(i);
        if (replacement instanceof Boolean) {
            return ((Boolean) replacement).booleanValue();
        }
        if (!(replacement instanceof XResForwarder)) {
            return XResources.super.getBoolean(i);
        }
        XResForwarder xResForwarder = (XResForwarder) replacement;
        return xResForwarder.getResources().getBoolean(xResForwarder.getId());
    }

    public int getColor(int i) throws Resources.NotFoundException {
        Object replacement = getReplacement(i);
        if (replacement instanceof Integer) {
            return ((Integer) replacement).intValue();
        }
        if (!(replacement instanceof XResForwarder)) {
            return XResources.super.getColor(i);
        }
        XResForwarder xResForwarder = (XResForwarder) replacement;
        return xResForwarder.getResources().getColor(xResForwarder.getId());
    }

    public ColorStateList getColorStateList(int i) throws Resources.NotFoundException {
        ColorStateList colorStateList;
        Object replacement = getReplacement(i);
        if (replacement instanceof ColorStateList) {
            return (ColorStateList) replacement;
        }
        if (replacement instanceof Integer) {
            int intValue = ((Integer) replacement).intValue();
            SparseArray<ColorStateList> sparseArray = sColorStateListCache;
            synchronized (sparseArray) {
                colorStateList = sparseArray.get(intValue);
                if (colorStateList == null) {
                    colorStateList = ColorStateList.valueOf(intValue);
                    sparseArray.put(intValue, colorStateList);
                }
            }
            return colorStateList;
        } else if (!(replacement instanceof XResForwarder)) {
            return XResources.super.getColorStateList(i);
        } else {
            XResForwarder xResForwarder = (XResForwarder) replacement;
            return xResForwarder.getResources().getColorStateList(xResForwarder.getId());
        }
    }

    public float getDimension(int i) throws Resources.NotFoundException {
        Object replacement = getReplacement(i);
        if (replacement instanceof DimensionReplacement) {
            return ((DimensionReplacement) replacement).getDimension(getDisplayMetrics());
        }
        if (!(replacement instanceof XResForwarder)) {
            return XResources.super.getDimension(i);
        }
        XResForwarder xResForwarder = (XResForwarder) replacement;
        return xResForwarder.getResources().getDimension(xResForwarder.getId());
    }

    public int getDimensionPixelOffset(int i) throws Resources.NotFoundException {
        Object replacement = getReplacement(i);
        if (replacement instanceof DimensionReplacement) {
            return ((DimensionReplacement) replacement).getDimensionPixelOffset(getDisplayMetrics());
        }
        if (!(replacement instanceof XResForwarder)) {
            return XResources.super.getDimensionPixelOffset(i);
        }
        XResForwarder xResForwarder = (XResForwarder) replacement;
        return xResForwarder.getResources().getDimensionPixelOffset(xResForwarder.getId());
    }

    public int getDimensionPixelSize(int i) throws Resources.NotFoundException {
        Object replacement = getReplacement(i);
        if (replacement instanceof DimensionReplacement) {
            return ((DimensionReplacement) replacement).getDimensionPixelSize(getDisplayMetrics());
        }
        if (!(replacement instanceof XResForwarder)) {
            return XResources.super.getDimensionPixelSize(i);
        }
        XResForwarder xResForwarder = (XResForwarder) replacement;
        return xResForwarder.getResources().getDimensionPixelSize(xResForwarder.getId());
    }

    public Drawable getDrawable(int i) throws Resources.NotFoundException {
        try {
            if (XposedHelpers.incrementMethodDepth("getDrawable") == 1) {
                Object replacement = getReplacement(i);
                if (replacement instanceof DrawableLoader) {
                    try {
                        Drawable newDrawable = ((DrawableLoader) replacement).newDrawable(this, i);
                        if (newDrawable != null) {
                            return newDrawable;
                        }
                    } catch (Throwable th) {
                        XposedBridge.log(th);
                    }
                } else if (replacement instanceof Integer) {
                    ColorDrawable colorDrawable = new ColorDrawable(((Integer) replacement).intValue());
                    XposedHelpers.decrementMethodDepth("getDrawable");
                    return colorDrawable;
                } else if (replacement instanceof XResForwarder) {
                    Drawable drawable = ((XResForwarder) replacement).getResources().getDrawable(((XResForwarder) replacement).getId());
                    XposedHelpers.decrementMethodDepth("getDrawable");
                    return drawable;
                }
            }
            Drawable drawable2 = XResources.super.getDrawable(i);
            XposedHelpers.decrementMethodDepth("getDrawable");
            return drawable2;
        } finally {
            XposedHelpers.decrementMethodDepth("getDrawable");
        }
    }

    public Drawable getDrawable(int i, Resources.Theme theme) throws Resources.NotFoundException {
        try {
            if (XposedHelpers.incrementMethodDepth("getDrawable") == 1) {
                Object replacement = getReplacement(i);
                if (replacement instanceof DrawableLoader) {
                    try {
                        Drawable newDrawable = ((DrawableLoader) replacement).newDrawable(this, i);
                        if (newDrawable != null) {
                            return newDrawable;
                        }
                    } catch (Throwable th) {
                        XposedBridge.log(th);
                    }
                } else if (replacement instanceof Integer) {
                    ColorDrawable colorDrawable = new ColorDrawable(((Integer) replacement).intValue());
                    XposedHelpers.decrementMethodDepth("getDrawable");
                    return colorDrawable;
                } else if (replacement instanceof XResForwarder) {
                    Drawable drawable = ((XResForwarder) replacement).getResources().getDrawable(((XResForwarder) replacement).getId());
                    XposedHelpers.decrementMethodDepth("getDrawable");
                    return drawable;
                }
            }
            Drawable drawable2 = XResources.super.getDrawable(i, theme);
            XposedHelpers.decrementMethodDepth("getDrawable");
            return drawable2;
        } finally {
            XposedHelpers.decrementMethodDepth("getDrawable");
        }
    }

    public Drawable getDrawableForDensity(int i, int i2) throws Resources.NotFoundException {
        try {
            if (XposedHelpers.incrementMethodDepth("getDrawableForDensity") == 1) {
                Object replacement = getReplacement(i);
                if (replacement instanceof DrawableLoader) {
                    try {
                        Drawable newDrawableForDensity = ((DrawableLoader) replacement).newDrawableForDensity(this, i, i2);
                        if (newDrawableForDensity != null) {
                            return newDrawableForDensity;
                        }
                    } catch (Throwable th) {
                        XposedBridge.log(th);
                    }
                } else if (replacement instanceof Integer) {
                    ColorDrawable colorDrawable = new ColorDrawable(((Integer) replacement).intValue());
                    XposedHelpers.decrementMethodDepth("getDrawableForDensity");
                    return colorDrawable;
                } else if (replacement instanceof XResForwarder) {
                    Drawable drawableForDensity = ((XResForwarder) replacement).getResources().getDrawableForDensity(((XResForwarder) replacement).getId(), i2);
                    XposedHelpers.decrementMethodDepth("getDrawableForDensity");
                    return drawableForDensity;
                }
            }
            Drawable drawableForDensity2 = XResources.super.getDrawableForDensity(i, i2);
            XposedHelpers.decrementMethodDepth("getDrawableForDensity");
            return drawableForDensity2;
        } finally {
            XposedHelpers.decrementMethodDepth("getDrawableForDensity");
        }
    }

    public Drawable getDrawableForDensity(int i, int i2, Resources.Theme theme) throws Resources.NotFoundException {
        try {
            if (XposedHelpers.incrementMethodDepth("getDrawableForDensity") == 1) {
                Object replacement = getReplacement(i);
                if (replacement instanceof DrawableLoader) {
                    try {
                        Drawable newDrawableForDensity = ((DrawableLoader) replacement).newDrawableForDensity(this, i, i2);
                        if (newDrawableForDensity != null) {
                            return newDrawableForDensity;
                        }
                    } catch (Throwable th) {
                        XposedBridge.log(th);
                    }
                } else if (replacement instanceof Integer) {
                    ColorDrawable colorDrawable = new ColorDrawable(((Integer) replacement).intValue());
                    XposedHelpers.decrementMethodDepth("getDrawableForDensity");
                    return colorDrawable;
                } else if (replacement instanceof XResForwarder) {
                    Drawable drawableForDensity = ((XResForwarder) replacement).getResources().getDrawableForDensity(((XResForwarder) replacement).getId(), i2);
                    XposedHelpers.decrementMethodDepth("getDrawableForDensity");
                    return drawableForDensity;
                }
            }
            Drawable drawableForDensity2 = XResources.super.getDrawableForDensity(i, i2, theme);
            XposedHelpers.decrementMethodDepth("getDrawableForDensity");
            return drawableForDensity2;
        } finally {
            XposedHelpers.decrementMethodDepth("getDrawableForDensity");
        }
    }

    public float getFloat(int i) {
        Object replacement = getReplacement(i);
        if (replacement instanceof Float) {
            return ((Float) replacement).floatValue();
        }
        if (!(replacement instanceof XResForwarder)) {
            return XResources.super.getFloat(i);
        }
        XResForwarder xResForwarder = (XResForwarder) replacement;
        return xResForwarder.getResources().getFloat(xResForwarder.getId());
    }

    public Typeface getFont(int i) {
        Object replacement = getReplacement(i);
        if (replacement instanceof Typeface) {
            return (Typeface) replacement;
        }
        if (!(replacement instanceof XResForwarder)) {
            return XResources.super.getFont(i);
        }
        XResForwarder xResForwarder = (XResForwarder) replacement;
        return xResForwarder.getResources().getFont(xResForwarder.getId());
    }

    public float getFraction(int i, int i2, int i3) {
        Object replacement = getReplacement(i);
        if (!(replacement instanceof XResForwarder)) {
            return XResources.super.getFraction(i, i2, i3);
        }
        XResForwarder xResForwarder = (XResForwarder) replacement;
        return xResForwarder.getResources().getFraction(xResForwarder.getId(), i2, i3);
    }

    public int getInteger(int i) throws Resources.NotFoundException {
        Object replacement = getReplacement(i);
        if (replacement instanceof Integer) {
            return ((Integer) replacement).intValue();
        }
        if (!(replacement instanceof XResForwarder)) {
            return XResources.super.getInteger(i);
        }
        XResForwarder xResForwarder = (XResForwarder) replacement;
        return xResForwarder.getResources().getInteger(xResForwarder.getId());
    }

    public int[] getIntArray(int i) throws Resources.NotFoundException {
        Object replacement = getReplacement(i);
        if (replacement instanceof int[]) {
            return (int[]) replacement;
        }
        if (!(replacement instanceof XResForwarder)) {
            return XResources.super.getIntArray(i);
        }
        XResForwarder xResForwarder = (XResForwarder) replacement;
        return xResForwarder.getResources().getIntArray(xResForwarder.getId());
    }

    public XmlResourceParser getLayout(int i) throws Resources.NotFoundException {
        XmlResourceParser xmlResourceParser;
        HashMap<String, XposedBridge.CopyOnWriteSortedSet<XC_LayoutInflated>> hashMap;
        XposedBridge.CopyOnWriteSortedSet<XC_LayoutInflated> copyOnWriteSortedSet;
        Object replacement = getReplacement(i);
        if (replacement instanceof XResForwarder) {
            XResForwarder xResForwarder = (XResForwarder) replacement;
            Resources resources = xResForwarder.getResources();
            int id = xResForwarder.getId();
            boolean isXmlCached = isXmlCached(resources, id);
            xmlResourceParser = resources.getLayout(id);
            if (!isXmlCached) {
                ResourcesHook.rewriteXmlReferencesNative(XposedHelpers.getLongField(xmlResourceParser, "mParseState"), this, resources);
            }
        } else {
            xmlResourceParser = XResources.super.getLayout(i);
        }
        SparseArray<HashMap<String, XposedBridge.CopyOnWriteSortedSet<XC_LayoutInflated>>> sparseArray = sLayoutCallbacks;
        synchronized (sparseArray) {
            hashMap = sparseArray.get(i);
        }
        if (hashMap != null) {
            synchronized (hashMap) {
                copyOnWriteSortedSet = hashMap.get(this.mResDir);
                if (copyOnWriteSortedSet == null && this.mResDir != null) {
                    copyOnWriteSortedSet = hashMap.get(null);
                }
            }
            if (copyOnWriteSortedSet != null) {
                String str = "layout";
                TypedValue typedValue = (TypedValue) XposedHelpers.getObjectField(this, "mTmpValue");
                getValue(i, typedValue, true);
                if (typedValue.type == 3) {
                    String[] split = typedValue.string.toString().split("/", 3);
                    if (split.length == 3) {
                        str = split[1];
                    } else {
                        XposedBridge.log("Unexpected resource path \"" + typedValue.string.toString() + "\" for resource id 0x" + Integer.toHexString(i));
                    }
                } else {
                    XposedBridge.log(new Resources.NotFoundException("Could not find file name for resource id 0x") + Integer.toHexString(i));
                }
                WeakHashMap<XmlResourceParser, XMLInstanceDetails> weakHashMap = sXmlInstanceDetails;
                synchronized (weakHashMap) {
                    SparseArray<HashMap<String, ResourceNames>> sparseArray2 = sResourceNames;
                    synchronized (sparseArray2) {
                        HashMap<String, ResourceNames> hashMap2 = sparseArray2.get(i);
                        if (hashMap2 != null) {
                            synchronized (hashMap2) {
                                XMLInstanceDetails xMLInstanceDetails = new XMLInstanceDetails(hashMap2.get(this.mResDir), str, copyOnWriteSortedSet);
                                weakHashMap.put(xmlResourceParser, xMLInstanceDetails);
                                XC_MethodHook.MethodHookParam peek = sIncludedLayouts.get().peek();
                                if (peek != null) {
                                    peek.setObjectExtra(EXTRA_XML_INSTANCE_DETAILS, xMLInstanceDetails);
                                }
                            }
                        }
                    }
                }
            }
        }
        return xmlResourceParser;
    }

    public Movie getMovie(int i) throws Resources.NotFoundException {
        Object replacement = getReplacement(i);
        if (!(replacement instanceof XResForwarder)) {
            return XResources.super.getMovie(i);
        }
        XResForwarder xResForwarder = (XResForwarder) replacement;
        return xResForwarder.getResources().getMovie(xResForwarder.getId());
    }

    public CharSequence getQuantityText(int i, int i2) throws Resources.NotFoundException {
        Object replacement = getReplacement(i);
        if (!(replacement instanceof XResForwarder)) {
            return XResources.super.getQuantityText(i, i2);
        }
        XResForwarder xResForwarder = (XResForwarder) replacement;
        return xResForwarder.getResources().getQuantityText(xResForwarder.getId(), i2);
    }

    public String[] getStringArray(int i) throws Resources.NotFoundException {
        Object replacement = getReplacement(i);
        if (replacement instanceof String[]) {
            return (String[]) replacement;
        }
        if (!(replacement instanceof XResForwarder)) {
            return XResources.super.getStringArray(i);
        }
        XResForwarder xResForwarder = (XResForwarder) replacement;
        return xResForwarder.getResources().getStringArray(xResForwarder.getId());
    }

    public CharSequence getText(int i) throws Resources.NotFoundException {
        Object replacement = getReplacement(i);
        if (replacement instanceof CharSequence) {
            return (CharSequence) replacement;
        }
        if (!(replacement instanceof XResForwarder)) {
            return XResources.super.getText(i);
        }
        XResForwarder xResForwarder = (XResForwarder) replacement;
        return xResForwarder.getResources().getText(xResForwarder.getId());
    }

    public CharSequence getText(int i, CharSequence charSequence) {
        Object replacement = getReplacement(i);
        if (replacement instanceof CharSequence) {
            return (CharSequence) replacement;
        }
        if (!(replacement instanceof XResForwarder)) {
            return XResources.super.getText(i, charSequence);
        }
        XResForwarder xResForwarder = (XResForwarder) replacement;
        return xResForwarder.getResources().getText(xResForwarder.getId(), charSequence);
    }

    public CharSequence[] getTextArray(int i) throws Resources.NotFoundException {
        Object replacement = getReplacement(i);
        if (replacement instanceof CharSequence[]) {
            return (CharSequence[]) replacement;
        }
        if (!(replacement instanceof XResForwarder)) {
            return XResources.super.getTextArray(i);
        }
        XResForwarder xResForwarder = (XResForwarder) replacement;
        return xResForwarder.getResources().getTextArray(xResForwarder.getId());
    }

    public void getValue(int i, TypedValue typedValue, boolean z) throws Resources.NotFoundException {
        Object replacement = getReplacement(i);
        if (replacement instanceof XResForwarder) {
            XResForwarder xResForwarder = (XResForwarder) replacement;
            xResForwarder.getResources().getValue(xResForwarder.getId(), typedValue, z);
            return;
        }
        if (replacement != null) {
            XposedBridge.log("Replacement of resource ID #0x" + Integer.toHexString(i) + " escaped because of deprecated replacement. Please use XResForwarder instead.");
        }
        XResources.super.getValue(i, typedValue, z);
    }

    public void getValueForDensity(int i, int i2, TypedValue typedValue, boolean z) throws Resources.NotFoundException {
        Object replacement = getReplacement(i);
        if (replacement instanceof XResForwarder) {
            XResForwarder xResForwarder = (XResForwarder) replacement;
            xResForwarder.getResources().getValueForDensity(xResForwarder.getId(), i2, typedValue, z);
            return;
        }
        if (replacement != null) {
            XposedBridge.log("Replacement of resource ID #0x" + Integer.toHexString(i) + " escaped because of deprecated replacement. Please use XResForwarder instead.");
        }
        XResources.super.getValueForDensity(i, i2, typedValue, z);
    }

    public XmlResourceParser getXml(int i) throws Resources.NotFoundException {
        Object replacement = getReplacement(i);
        if (!(replacement instanceof XResForwarder)) {
            return XResources.super.getXml(i);
        }
        XResForwarder xResForwarder = (XResForwarder) replacement;
        Resources resources = xResForwarder.getResources();
        int id = xResForwarder.getId();
        boolean isXmlCached = isXmlCached(resources, id);
        XmlResourceParser xml = resources.getXml(id);
        if (!isXmlCached) {
            ResourcesHook.rewriteXmlReferencesNative(XposedHelpers.getLongField(xml, "mParseState"), this, resources);
        }
        return xml;
    }

    private static boolean isXmlCached(Resources resources, int i) {
        int[] iArr = (int[]) XposedHelpers.getObjectField(XposedHelpers.getObjectField(resources, "mResourcesImpl"), "mCachedXmlBlockCookies");
        synchronized (iArr) {
            for (int i2 : iArr) {
                if (i2 == i) {
                    return true;
                }
            }
            return false;
        }
    }

    /* JADX WARNING: Removed duplicated region for block: B:23:0x0055  */
    private static int translateResId(int i, XResources xResources, Resources resources) {
        int i2;
        boolean z;
        try {
            String resourceEntryName = resources.getResourceEntryName(i);
            String resourceTypeName = resources.getResourceTypeName(i);
            try {
                i2 = xResources.getIdentifier(resourceEntryName, resourceTypeName, xResources.mPackageName);
            } catch (Resources.NotFoundException unused) {
                i2 = 0;
            }
            try {
                TypedValue typedValue = new TypedValue();
                resources.getValue(i, typedValue, false);
                if (!(typedValue.type == 18 && typedValue.data == 0)) {
                    z = true;
                    if (!z || i2 != 0 || resourceTypeName.equals("id")) {
                        if (i2 == 0) {
                            i2 = getFakeResId(resources, i);
                        }
                        if (z && !resourceTypeName.equals("id")) {
                            xResources.setReplacement(i2, new XResForwarder(resources, i));
                        }
                        return i2;
                    }
                    XposedBridge.log(resourceTypeName + "/" + resourceEntryName + " is neither defined in module nor in original resources");
                    return 0;
                }
            } catch (Resources.NotFoundException unused2) {
            }
            z = false;
            if (!z) {
            }
            if (i2 == 0) {
            }
            xResources.setReplacement(i2, new XResForwarder(resources, i));
            return i2;
        } catch (Exception e) {
            XposedBridge.log(e);
            return i;
        }
    }

    public static int getFakeResId(String str) {
        return (str.hashCode() & 16777215) | 2113929216;
    }

    public static int getFakeResId(Resources resources, int i) {
        return getFakeResId(resources.getResourceName(i));
    }

    public int addResource(Resources resources, int i) {
        int fakeResId = getFakeResId(resources, i);
        SparseArray<HashMap<String, Object>> sparseArray = sReplacements;
        synchronized (sparseArray) {
            if (sparseArray.indexOfKey(fakeResId) < 0) {
                setReplacement(fakeResId, new XResForwarder(resources, i));
            }
        }
        return fakeResId;
    }

    private static int translateAttrId(String str, XResources xResources) {
        try {
            return xResources.getIdentifier(str, "attr", xResources.mPackageName);
        } catch (Resources.NotFoundException unused) {
            XposedBridge.log("Attribute " + str + " not found in original resources");
            return 0;
        }
    }

    public static class XTypedArray extends XTypedArraySuperClass {
        public XTypedArray(Resources resources) {
            super(resources);
        }

        public boolean getBoolean(int i, boolean z) {
            Object replacement = ((XResources) getResources()).getReplacement(getResourceId(i, 0));
            if (replacement instanceof Boolean) {
                return ((Boolean) replacement).booleanValue();
            }
            if (!(replacement instanceof XResForwarder)) {
                return XResources.super.getBoolean(i, z);
            }
            XResForwarder xResForwarder = (XResForwarder) replacement;
            return xResForwarder.getResources().getBoolean(xResForwarder.getId());
        }

        public int getColor(int i, int i2) {
            Object replacement = ((XResources) getResources()).getReplacement(getResourceId(i, 0));
            if (replacement instanceof Integer) {
                return ((Integer) replacement).intValue();
            }
            if (!(replacement instanceof XResForwarder)) {
                return XResources.super.getColor(i, i2);
            }
            XResForwarder xResForwarder = (XResForwarder) replacement;
            return xResForwarder.getResources().getColor(xResForwarder.getId());
        }

        public ColorStateList getColorStateList(int i) {
            ColorStateList colorStateList;
            Object replacement = ((XResources) getResources()).getReplacement(getResourceId(i, 0));
            if (replacement instanceof ColorStateList) {
                return (ColorStateList) replacement;
            }
            if (replacement instanceof Integer) {
                int intValue = ((Integer) replacement).intValue();
                synchronized (XResources.sColorStateListCache) {
                    colorStateList = (ColorStateList) XResources.sColorStateListCache.get(intValue);
                    if (colorStateList == null) {
                        colorStateList = ColorStateList.valueOf(intValue);
                        XResources.sColorStateListCache.put(intValue, colorStateList);
                    }
                }
                return colorStateList;
            } else if (!(replacement instanceof XResForwarder)) {
                return XResources.super.getColorStateList(i);
            } else {
                XResForwarder xResForwarder = (XResForwarder) replacement;
                return xResForwarder.getResources().getColorStateList(xResForwarder.getId());
            }
        }

        public float getDimension(int i, float f) {
            Object replacement = ((XResources) getResources()).getReplacement(getResourceId(i, 0));
            if (!(replacement instanceof XResForwarder)) {
                return XResources.super.getDimension(i, f);
            }
            XResForwarder xResForwarder = (XResForwarder) replacement;
            return xResForwarder.getResources().getDimension(xResForwarder.getId());
        }

        public int getDimensionPixelOffset(int i, int i2) {
            Object replacement = ((XResources) getResources()).getReplacement(getResourceId(i, 0));
            if (!(replacement instanceof XResForwarder)) {
                return XResources.super.getDimensionPixelOffset(i, i2);
            }
            XResForwarder xResForwarder = (XResForwarder) replacement;
            return xResForwarder.getResources().getDimensionPixelOffset(xResForwarder.getId());
        }

        public int getDimensionPixelSize(int i, int i2) {
            Object replacement = ((XResources) getResources()).getReplacement(getResourceId(i, 0));
            if (!(replacement instanceof XResForwarder)) {
                return XResources.super.getDimensionPixelSize(i, i2);
            }
            XResForwarder xResForwarder = (XResForwarder) replacement;
            return xResForwarder.getResources().getDimensionPixelSize(xResForwarder.getId());
        }

        public Drawable getDrawable(int i) {
            int resourceId = getResourceId(i, 0);
            XResources xResources = (XResources) getResources();
            Object replacement = xResources.getReplacement(resourceId);
            if (replacement instanceof DrawableLoader) {
                try {
                    Drawable newDrawable = ((DrawableLoader) replacement).newDrawable(xResources, resourceId);
                    if (newDrawable != null) {
                        return newDrawable;
                    }
                } catch (Throwable th) {
                    XposedBridge.log(th);
                }
            } else if (replacement instanceof Integer) {
                return new ColorDrawable(((Integer) replacement).intValue());
            } else {
                if (replacement instanceof XResForwarder) {
                    XResForwarder xResForwarder = (XResForwarder) replacement;
                    return xResForwarder.getResources().getDrawable(xResForwarder.getId());
                }
            }
            return XResources.super.getDrawable(i);
        }

        public float getFloat(int i, float f) {
            Object replacement = ((XResources) getResources()).getReplacement(getResourceId(i, 0));
            if (!(replacement instanceof XResForwarder)) {
                return XResources.super.getFloat(i, f);
            }
            XResForwarder xResForwarder = (XResForwarder) replacement;
            return xResForwarder.getResources().getDimension(xResForwarder.getId());
        }

        public Typeface getFont(int i) {
            Object replacement = ((XResources) getResources()).getReplacement(getResourceId(i, 0));
            if (replacement instanceof Typeface) {
                return (Typeface) replacement;
            }
            if (!(replacement instanceof XResForwarder)) {
                return XResources.super.getFont(i);
            }
            XResForwarder xResForwarder = (XResForwarder) replacement;
            return xResForwarder.getResources().getFont(xResForwarder.getId());
        }

        public float getFraction(int i, int i2, int i3, float f) {
            Object replacement = ((XResources) getResources()).getReplacement(getResourceId(i, 0));
            if (!(replacement instanceof XResForwarder)) {
                return XResources.super.getFraction(i, i2, i3, f);
            }
            XResForwarder xResForwarder = (XResForwarder) replacement;
            return xResForwarder.getResources().getFraction(xResForwarder.getId(), i2, i3);
        }

        public int getInt(int i, int i2) {
            Object replacement = ((XResources) getResources()).getReplacement(getResourceId(i, 0));
            if (replacement instanceof Integer) {
                return ((Integer) replacement).intValue();
            }
            if (!(replacement instanceof XResForwarder)) {
                return XResources.super.getInt(i, i2);
            }
            XResForwarder xResForwarder = (XResForwarder) replacement;
            return xResForwarder.getResources().getInteger(xResForwarder.getId());
        }

        public int getInteger(int i, int i2) {
            Object replacement = ((XResources) getResources()).getReplacement(getResourceId(i, 0));
            if (replacement instanceof Integer) {
                return ((Integer) replacement).intValue();
            }
            if (!(replacement instanceof XResForwarder)) {
                return XResources.super.getInteger(i, i2);
            }
            XResForwarder xResForwarder = (XResForwarder) replacement;
            return xResForwarder.getResources().getInteger(xResForwarder.getId());
        }

        public int getLayoutDimension(int i, int i2) {
            Object replacement = ((XResources) getResources()).getReplacement(getResourceId(i, 0));
            if (!(replacement instanceof XResForwarder)) {
                return XResources.super.getLayoutDimension(i, i2);
            }
            XResForwarder xResForwarder = (XResForwarder) replacement;
            return xResForwarder.getResources().getDimensionPixelSize(xResForwarder.getId());
        }

        public int getLayoutDimension(int i, String str) {
            Object replacement = ((XResources) getResources()).getReplacement(getResourceId(i, 0));
            if (!(replacement instanceof XResForwarder)) {
                return XResources.super.getLayoutDimension(i, str);
            }
            XResForwarder xResForwarder = (XResForwarder) replacement;
            return xResForwarder.getResources().getDimensionPixelSize(xResForwarder.getId());
        }

        public String getString(int i) {
            Object replacement = ((XResources) getResources()).getReplacement(getResourceId(i, 0));
            if (replacement instanceof CharSequence) {
                return replacement.toString();
            }
            if (!(replacement instanceof XResForwarder)) {
                return XResources.super.getString(i);
            }
            XResForwarder xResForwarder = (XResForwarder) replacement;
            return xResForwarder.getResources().getString(xResForwarder.getId());
        }

        public CharSequence getText(int i) {
            Object replacement = ((XResources) getResources()).getReplacement(getResourceId(i, 0));
            if (replacement instanceof CharSequence) {
                return (CharSequence) replacement;
            }
            if (!(replacement instanceof XResForwarder)) {
                return XResources.super.getText(i);
            }
            XResForwarder xResForwarder = (XResForwarder) replacement;
            return xResForwarder.getResources().getText(xResForwarder.getId());
        }

        public CharSequence[] getTextArray(int i) {
            Object replacement = ((XResources) getResources()).getReplacement(getResourceId(i, 0));
            if (replacement instanceof CharSequence[]) {
                return (CharSequence[]) replacement;
            }
            if (!(replacement instanceof XResForwarder)) {
                return XResources.super.getTextArray(i);
            }
            XResForwarder xResForwarder = (XResForwarder) replacement;
            return xResForwarder.getResources().getTextArray(xResForwarder.getId());
        }

        public boolean getValue(int i, TypedValue typedValue) {
            int resourceId = getResourceId(i, 0);
            Object replacement = ((XResources) getResources()).getReplacement(resourceId);
            if (replacement instanceof XResForwarder) {
                XResForwarder xResForwarder = (XResForwarder) replacement;
                xResForwarder.getResources().getValue(xResForwarder.getId(), typedValue, true);
                if (typedValue.type != 0) {
                    return true;
                }
                return false;
            }
            if (replacement != null) {
                XposedBridge.log("Replacement of resource ID #0x" + Integer.toHexString(resourceId) + " escaped because of deprecated replacement. Please use XResForwarder instead.");
            }
            return XResources.super.getValue(i, typedValue);
        }

        public TypedValue peekValue(int i) {
            int resourceId = getResourceId(i, 0);
            Object replacement = ((XResources) getResources()).getReplacement(resourceId);
            if (!(replacement instanceof XResForwarder)) {
                if (replacement != null) {
                    XposedBridge.log("Replacement of resource ID #0x" + Integer.toHexString(resourceId) + " escaped because of deprecated replacement. Please use XResForwarder instead.");
                }
                return XResources.super.peekValue(i);
            } else if (!XposedHelpers.getBooleanField(this, "mRecycled")) {
                TypedValue typedValue = (TypedValue) XposedHelpers.getObjectField(this, "mValue");
                XResForwarder xResForwarder = (XResForwarder) replacement;
                xResForwarder.getResources().getValue(xResForwarder.getId(), typedValue, true);
                return typedValue;
            } else {
                throw new RuntimeException("Cannot make calls to a recycled instance!");
            }
        }
    }

    public static abstract class DrawableLoader {
        public abstract Drawable newDrawable(XResources xResources, int i) throws Throwable;

        public Drawable newDrawableForDensity(XResources xResources, int i, int i2) throws Throwable {
            return newDrawable(xResources, i);
        }
    }

    public static class DimensionReplacement {
        private final int mUnit;
        private final float mValue;

        public DimensionReplacement(float f, int i) {
            this.mValue = f;
            this.mUnit = i;
        }

        public float getDimension(DisplayMetrics displayMetrics) {
            return TypedValue.applyDimension(this.mUnit, this.mValue, displayMetrics);
        }

        public int getDimensionPixelOffset(DisplayMetrics displayMetrics) {
            return (int) TypedValue.applyDimension(this.mUnit, this.mValue, displayMetrics);
        }

        public int getDimensionPixelSize(DisplayMetrics displayMetrics) {
            int applyDimension = (int) (TypedValue.applyDimension(this.mUnit, this.mValue, displayMetrics) + 0.5f);
            if (applyDimension != 0) {
                return applyDimension;
            }
            float f = this.mValue;
            if (f == 0.0f) {
                return 0;
            }
            return f > 0.0f ? 1 : -1;
        }
    }

    /* access modifiers changed from: private */
    public class XMLInstanceDetails {
        public final XposedBridge.CopyOnWriteSortedSet<XC_LayoutInflated> callbacks;
        public final XResources res;
        public final ResourceNames resNames;
        public final String variant;

        private XMLInstanceDetails(ResourceNames resourceNames, String str, XposedBridge.CopyOnWriteSortedSet<XC_LayoutInflated> copyOnWriteSortedSet) {
            this.res = XResources.this;
            this.resNames = resourceNames;
            this.variant = str;
            this.callbacks = copyOnWriteSortedSet;
        }
    }

    public XC_LayoutInflated.Unhook hookLayout(int i, XC_LayoutInflated xC_LayoutInflated) {
        return hookLayoutInternal(this.mResDir, i, getResourceNames(i), xC_LayoutInflated);
    }

    @Deprecated
    public XC_LayoutInflated.Unhook hookLayout(String str, XC_LayoutInflated xC_LayoutInflated) {
        int identifier = getIdentifier(str, null, null);
        if (identifier != 0) {
            return hookLayout(identifier, xC_LayoutInflated);
        }
        throw new Resources.NotFoundException(str);
    }

    public XC_LayoutInflated.Unhook hookLayout(String str, String str2, String str3, XC_LayoutInflated xC_LayoutInflated) {
        int identifier = getIdentifier(str3, str2, str);
        if (identifier != 0) {
            return hookLayout(identifier, xC_LayoutInflated);
        }
        throw new Resources.NotFoundException(str + ":" + str2 + "/" + str3);
    }

    public static XC_LayoutInflated.Unhook hookSystemWideLayout(int i, XC_LayoutInflated xC_LayoutInflated) {
        if (i < 2130706432) {
            return hookLayoutInternal(null, i, getSystemResourceNames(i), xC_LayoutInflated);
        }
        throw new IllegalArgumentException("ids >= 0x7f000000 are app specific and cannot be set for the framework");
    }

    @Deprecated
    public static XC_LayoutInflated.Unhook hookSystemWideLayout(String str, XC_LayoutInflated xC_LayoutInflated) {
        int identifier = getSystem().getIdentifier(str, null, null);
        if (identifier != 0) {
            return hookSystemWideLayout(identifier, xC_LayoutInflated);
        }
        throw new Resources.NotFoundException(str);
    }

    public static XC_LayoutInflated.Unhook hookSystemWideLayout(String str, String str2, String str3, XC_LayoutInflated xC_LayoutInflated) {
        int identifier = getSystem().getIdentifier(str3, str2, str);
        if (identifier != 0) {
            return hookSystemWideLayout(identifier, xC_LayoutInflated);
        }
        throw new Resources.NotFoundException(str + ":" + str2 + "/" + str3);
    }

    private static XC_LayoutInflated.Unhook hookLayoutInternal(String str, int i, ResourceNames resourceNames, XC_LayoutInflated xC_LayoutInflated) {
        HashMap<String, XposedBridge.CopyOnWriteSortedSet<XC_LayoutInflated>> hashMap;
        XposedBridge.CopyOnWriteSortedSet<XC_LayoutInflated> copyOnWriteSortedSet;
        if (i != 0) {
            if (str == null) {
                try {
                    XposedInit.hookResources();
                } catch (Throwable th) {
                    throw new IllegalStateException("Failed to initialize resources hook", th);
                }
            }
            SparseArray<HashMap<String, XposedBridge.CopyOnWriteSortedSet<XC_LayoutInflated>>> sparseArray = sLayoutCallbacks;
            synchronized (sparseArray) {
                hashMap = sparseArray.get(i);
                if (hashMap == null) {
                    hashMap = new HashMap<>();
                    sparseArray.put(i, hashMap);
                }
            }
            synchronized (hashMap) {
                copyOnWriteSortedSet = hashMap.get(str);
                if (copyOnWriteSortedSet == null) {
                    copyOnWriteSortedSet = new XposedBridge.CopyOnWriteSortedSet<>();
                    hashMap.put(str, copyOnWriteSortedSet);
                }
            }
            copyOnWriteSortedSet.add(xC_LayoutInflated);
            putResourceNames(str, resourceNames);
            Objects.requireNonNull(xC_LayoutInflated);
            return new XC_LayoutInflated.Unhook(str, i);
        }
        throw new IllegalArgumentException("id 0 is not an allowed resource identifier");
    }

    /* JADX WARNING: Code restructure failed: missing block: B:10:?, code lost:
        r1 = r2.get(r1);
     */
    /* JADX WARNING: Code restructure failed: missing block: B:11:0x0015, code lost:
        if (r1 != null) goto L_0x0019;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:12:0x0017, code lost:
        monitor-exit(r2);
     */
    /* JADX WARNING: Code restructure failed: missing block: B:13:0x0018, code lost:
        return;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:14:0x0019, code lost:
        monitor-exit(r2);
     */
    /* JADX WARNING: Code restructure failed: missing block: B:15:0x001a, code lost:
        r1.remove(r3);
     */
    /* JADX WARNING: Code restructure failed: missing block: B:16:0x001d, code lost:
        return;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:8:0x000e, code lost:
        monitor-enter(r2);
     */
    public static void unhookLayout(String str, int i, XC_LayoutInflated xC_LayoutInflated) {
        SparseArray<HashMap<String, XposedBridge.CopyOnWriteSortedSet<XC_LayoutInflated>>> sparseArray = sLayoutCallbacks;
        synchronized (sparseArray) {
            HashMap<String, XposedBridge.CopyOnWriteSortedSet<XC_LayoutInflated>> hashMap = sparseArray.get(i);
            if (hashMap == null) {
            }
        }
    }
}
