package de.robv.android.xposed;

import android.content.SharedPreferences;
import android.os.Environment;
import android.util.Log;
import com.android.internal.util.XmlUtils;
import de.robv.android.xposed.services.FileResult;
import java.io.File;
import java.io.FileNotFoundException;
import java.io.IOException;
import java.io.InputStream;
import java.nio.file.AccessDeniedException;
import java.nio.file.ClosedWatchServiceException;
import java.nio.file.Path;
import java.nio.file.StandardWatchEventKinds;
import java.nio.file.WatchEvent;
import java.nio.file.WatchKey;
import java.nio.file.WatchService;
import java.security.MessageDigest;
import java.util.Arrays;
import java.util.HashMap;
import java.util.Map;
import java.util.Set;
import org.lsposed.lspd.core.ApplicationServiceClient;
import org.lsposed.lspd.util.MetaDataReader;
import org.xmlpull.v1.XmlPullParserException;

public final class XSharedPreferences implements SharedPreferences {
    private static final String TAG = "XSharedPreferences";
    private static final Object sContent = new Object();
    private static WatchService sWatcher;
    private static Thread sWatcherDaemon = null;
    private static final HashMap<WatchKey, PrefsData> sWatcherKeyInstances = new HashMap<>();
    private final File mFile;
    private long mFileSize;
    private final String mFilename;
    private long mLastModified;
    private final HashMap<SharedPreferences.OnSharedPreferenceChangeListener, Object> mListeners;
    private boolean mLoaded;
    private Map<String, Object> mMap;
    private WatchKey mWatchKey;

    private static void initWatcherDaemon() {
        AnonymousClass1 r0 = new Thread() {
            /* class de.robv.android.xposed.XSharedPreferences.AnonymousClass1 */

            public void run() {
                while (true) {
                    try {
                        WatchKey take = XSharedPreferences.sWatcher.take();
                        for (WatchEvent<?> watchEvent : take.pollEvents()) {
                            WatchEvent.Kind<?> kind = watchEvent.kind();
                            if (kind != StandardWatchEventKinds.OVERFLOW) {
                                String path = ((Path) take.watchable()).resolve((Path) watchEvent.context()).toString();
                                if (path.endsWith(".bak")) {
                                    if (kind != StandardWatchEventKinds.ENTRY_DELETE) {
                                    }
                                } else if (SELinuxHelper.getAppDataFileService().checkFileExists(path + ".bak")) {
                                }
                                PrefsData prefsData = (PrefsData) XSharedPreferences.sWatcherKeyInstances.get(take);
                                if (prefsData != null && prefsData.hasChanged()) {
                                    for (SharedPreferences.OnSharedPreferenceChangeListener onSharedPreferenceChangeListener : prefsData.mPrefs.mListeners.keySet()) {
                                        try {
                                            onSharedPreferenceChangeListener.onSharedPreferenceChanged(prefsData.mPrefs, null);
                                        } catch (Throwable unused) {
                                        }
                                    }
                                }
                            }
                        }
                        take.reset();
                    } catch (ClosedWatchServiceException unused2) {
                        XSharedPreferences.sWatcher = null;
                        return;
                    } catch (InterruptedException unused3) {
                        return;
                    }
                }
            }
        };
        sWatcherDaemon = r0;
        r0.setName("XSharedPreferences-Daemon");
        sWatcherDaemon.setDaemon(true);
        sWatcherDaemon.start();
    }

    public XSharedPreferences(File file) {
        this.mListeners = new HashMap<>();
        this.mLoaded = false;
        this.mFile = file;
        this.mFilename = file.getAbsolutePath();
        init();
    }

    public XSharedPreferences(String str) {
        this(str, str + "_preferences");
    }

    /* JADX WARNING: Removed duplicated region for block: B:24:0x008e  */
    /* JADX WARNING: Removed duplicated region for block: B:36:0x0017 A[ADDED_TO_REGION, SYNTHETIC] */
    public XSharedPreferences(String str, String str2) {
        boolean z;
        boolean z2;
        boolean z3;
        Object e;
        this.mListeners = new HashMap<>();
        this.mLoaded = false;
        loop0:
        while (true) {
            z = false;
            for (String str3 : XposedInit.getLoadedModules()) {
                if (str3.contains("/" + str + "-")) {
                    int i = -1;
                    try {
                        Map<String, Object> metaData = MetaDataReader.getMetaData(new File(str3));
                        z2 = metaData.containsKey("xposedminversion");
                        if (z2) {
                            try {
                                Object obj = metaData.get("xposedminversion");
                                if (obj instanceof Integer) {
                                    i = ((Integer) obj).intValue();
                                } else if (obj instanceof String) {
                                    i = MetaDataReader.extractIntPart((String) obj);
                                }
                                z3 = metaData.containsKey("xposedsharedprefs");
                            } catch (IOException | NumberFormatException e2) {
                                e = e2;
                                Log.w(TAG, "Apk parser fails: " + e);
                                z3 = false;
                                if (!z2) {
                                }
                            }
                            if (!z2 && (i > 92 || z3)) {
                                z = true;
                            }
                        }
                    } catch (IOException | NumberFormatException e3) {
                        e = e3;
                        z2 = false;
                        Log.w(TAG, "Apk parser fails: " + e);
                        z3 = false;
                        if (!z2) {
                        }
                    }
                    z3 = false;
                    if (!z2) {
                    }
                }
            }
            break loop0;
        }
        if (z) {
            this.mFile = new File(ApplicationServiceClient.serviceClient.getPrefsPath(str), str2 + ".xml");
        } else {
            this.mFile = new File(Environment.getDataDirectory(), "data/" + str + "/shared_prefs/" + str2 + ".xml");
        }
        this.mFilename = this.mFile.getAbsolutePath();
        init();
    }

    private void tryRegisterWatcher() {
        WatchKey watchKey = this.mWatchKey;
        if (watchKey == null || !watchKey.isValid()) {
            HashMap<WatchKey, PrefsData> hashMap = sWatcherKeyInstances;
            synchronized (hashMap) {
                Path path = this.mFile.toPath();
                try {
                    if (sWatcher == null) {
                        sWatcher = new File(ApplicationServiceClient.serviceClient.getPrefsPath("")).toPath().getFileSystem().newWatchService();
                    }
                    WatchKey register = path.getParent().register(sWatcher, StandardWatchEventKinds.ENTRY_CREATE, StandardWatchEventKinds.ENTRY_MODIFY, StandardWatchEventKinds.ENTRY_DELETE);
                    this.mWatchKey = register;
                    hashMap.put(register, new PrefsData(this));
                    Thread thread = sWatcherDaemon;
                    if (thread == null || !thread.isAlive()) {
                        initWatcherDaemon();
                    }
                } catch (AccessDeniedException unused) {
                } catch (Exception e) {
                    Log.e(TAG, "tryRegisterWatcher: failed to register file watcher", e);
                }
            }
        }
    }

    private void tryUnregisterWatcher() {
        HashMap<WatchKey, PrefsData> hashMap = sWatcherKeyInstances;
        synchronized (hashMap) {
            WatchKey watchKey = this.mWatchKey;
            if (watchKey != null) {
                hashMap.remove(watchKey);
                this.mWatchKey.cancel();
                this.mWatchKey = null;
            }
            boolean z = false;
            for (WatchKey watchKey2 : hashMap.keySet()) {
                z |= watchKey2.isValid();
            }
            if (!z) {
                try {
                    sWatcher.close();
                } catch (Exception unused) {
                }
            }
        }
    }

    private void init() {
        startLoadFromDisk();
    }

    /* access modifiers changed from: private */
    public static long tryGetFileSize(String str) {
        try {
            return SELinuxHelper.getAppDataFileService().getFileSize(str);
        } catch (IOException unused) {
            return 0;
        }
    }

    /* access modifiers changed from: private */
    public static byte[] tryGetFileHash(String str) {
        try {
            MessageDigest instance = MessageDigest.getInstance("MD5");
            InputStream fileInputStream = SELinuxHelper.getAppDataFileService().getFileInputStream(str);
            try {
                byte[] bArr = new byte[4096];
                while (true) {
                    int read = fileInputStream.read(bArr);
                    if (read == -1) {
                        break;
                    }
                    instance.update(bArr, 0, read);
                }
                if (fileInputStream != null) {
                    fileInputStream.close();
                }
                return instance.digest();
            } catch (Throwable th) {
                th.addSuppressed(th);
            }
            throw th;
        } catch (Exception unused) {
            return new byte[0];
        }
    }

    public boolean makeWorldReadable() {
        if (!SELinuxHelper.getAppDataFileService().hasDirectFileAccess() || !this.mFile.exists() || !this.mFile.setReadable(true, false)) {
            return false;
        }
        if (this.mFile.getParentFile() != null) {
            this.mFile.getParentFile().setReadable(true, false);
        }
        if (!this.mListeners.isEmpty()) {
            tryRegisterWatcher();
        }
        return true;
    }

    public File getFile() {
        return this.mFile;
    }

    private void startLoadFromDisk() {
        synchronized (this) {
            this.mLoaded = false;
        }
        new Thread("XSharedPreferences-load") {
            /* class de.robv.android.xposed.XSharedPreferences.AnonymousClass2 */

            public void run() {
                synchronized (XSharedPreferences.this) {
                    XSharedPreferences.this.loadFromDiskLocked();
                }
            }
        }.start();
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    /* JADX WARNING: Code restructure failed: missing block: B:57:0x00a1, code lost:
        r0 = move-exception;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:58:0x00a2, code lost:
        throw r0;
     */
    /* JADX WARNING: Exception block dominator not found, dom blocks: [B:34:0x0067, B:55:0x009b] */
    /* JADX WARNING: Removed duplicated region for block: B:60:? A[ExcHandler: Exception (unused java.lang.Exception), PHI: r2 r3 
      PHI: (r2v4 de.robv.android.xposed.services.FileResult) = (r2v7 de.robv.android.xposed.services.FileResult), (r2v7 de.robv.android.xposed.services.FileResult), (r2v10 de.robv.android.xposed.services.FileResult), (r2v10 de.robv.android.xposed.services.FileResult) binds: [B:55:0x009b, B:56:?, B:34:0x0067, B:35:?] A[DONT_GENERATE, DONT_INLINE]
      PHI: (r3v1 java.util.Map<java.lang.String, java.lang.Object>) = (r3v4 java.util.Map<java.lang.String, java.lang.Object>), (r3v4 java.util.Map<java.lang.String, java.lang.Object>), (r3v7 java.util.Map<java.lang.String, java.lang.Object>), (r3v7 java.util.Map<java.lang.String, java.lang.Object>) binds: [B:55:0x009b, B:56:?, B:34:0x0067, B:35:?] A[DONT_GENERATE, DONT_INLINE], SYNTHETIC, Splitter:B:34:0x0067] */
    /* JADX WARNING: Removed duplicated region for block: B:64:0x00ab  */
    /* JADX WARNING: Removed duplicated region for block: B:65:0x00b6  */
    private void loadFromDiskLocked() {
        Throwable th;
        FileResult fileResult;
        Map<String, Object> map;
        Map<String, Object> map2;
        XmlPullParserException e;
        Map<String, Object> map3;
        IOException e2;
        if (!this.mLoaded) {
            FileResult fileResult2 = null;
            try {
                fileResult = SELinuxHelper.getAppDataFileService().getFileInputStream(this.mFilename, this.mFileSize, this.mLastModified);
                try {
                    if (fileResult.stream != null) {
                        map = XmlUtils.readMapXml(fileResult.stream);
                        fileResult.stream.close();
                    } else {
                        map = this.mMap;
                    }
                    if (!(fileResult == null || fileResult.stream == null)) {
                        try {
                            fileResult.stream.close();
                        } catch (RuntimeException e3) {
                            throw e3;
                        } catch (Exception unused) {
                        }
                    }
                } catch (XmlPullParserException e4) {
                    e = e4;
                    map2 = null;
                    fileResult2 = fileResult;
                    Log.w(TAG, "getSharedPreferences failed for: " + this.mFilename, e);
                    fileResult2.stream.close();
                    fileResult = fileResult2;
                    map = map2;
                    this.mLoaded = true;
                    if (map != null) {
                    }
                    notifyAll();
                } catch (FileNotFoundException unused2) {
                    map3 = null;
                    fileResult2 = fileResult;
                    try {
                        fileResult2.stream.close();
                    } catch (RuntimeException e5) {
                        throw e5;
                    } catch (Exception unused3) {
                    }
                    fileResult = fileResult2;
                    map = map3;
                    this.mLoaded = true;
                    if (map != null) {
                    }
                    notifyAll();
                } catch (IOException e6) {
                    e2 = e6;
                    map2 = null;
                    fileResult2 = fileResult;
                    try {
                        Log.w(TAG, "getSharedPreferences failed for: " + this.mFilename, e2);
                        try {
                            fileResult2.stream.close();
                        } catch (RuntimeException e7) {
                            throw e7;
                        } catch (Exception unused4) {
                        }
                        fileResult = fileResult2;
                        map = map2;
                        this.mLoaded = true;
                        if (map != null) {
                        }
                        notifyAll();
                    } catch (Throwable th2) {
                        th = th2;
                        try {
                            fileResult2.stream.close();
                        } catch (RuntimeException e8) {
                            throw e8;
                        } catch (Exception unused5) {
                        }
                        throw th;
                    }
                } catch (Throwable th3) {
                    th = th3;
                    fileResult2 = fileResult;
                    if (!(fileResult2 == null || fileResult2.stream == null)) {
                        fileResult2.stream.close();
                    }
                    throw th;
                }
            } catch (XmlPullParserException e9) {
                e = e9;
                map2 = null;
                Log.w(TAG, "getSharedPreferences failed for: " + this.mFilename, e);
                if (!(fileResult2 == null || fileResult2.stream == null)) {
                    fileResult2.stream.close();
                }
                fileResult = fileResult2;
                map = map2;
                this.mLoaded = true;
                if (map != null) {
                }
                notifyAll();
            } catch (FileNotFoundException unused6) {
                map3 = null;
                if (!(fileResult2 == null || fileResult2.stream == null)) {
                    fileResult2.stream.close();
                }
                fileResult = fileResult2;
                map = map3;
                this.mLoaded = true;
                if (map != null) {
                }
                notifyAll();
            } catch (IOException e10) {
                e2 = e10;
                map2 = null;
                Log.w(TAG, "getSharedPreferences failed for: " + this.mFilename, e2);
                if (!(fileResult2 == null || fileResult2.stream == null)) {
                    fileResult2.stream.close();
                }
                fileResult = fileResult2;
                map = map2;
                this.mLoaded = true;
                if (map != null) {
                }
                notifyAll();
            }
            this.mLoaded = true;
            if (map != null) {
                this.mMap = map;
                this.mLastModified = fileResult.mtime;
                this.mFileSize = fileResult.size;
            } else {
                this.mMap = new HashMap();
            }
            notifyAll();
        }
    }

    public synchronized void reload() {
        if (hasFileChanged()) {
            init();
        }
    }

    public synchronized boolean hasFileChanged() {
        boolean z;
        z = true;
        try {
            FileResult statFile = SELinuxHelper.getAppDataFileService().statFile(this.mFilename);
            if (this.mLastModified == statFile.mtime && this.mFileSize == statFile.size) {
                z = false;
            }
        } catch (FileNotFoundException unused) {
            return true;
        } catch (IOException e) {
            Log.w(TAG, "hasFileChanged", e);
            return true;
        }
        return z;
    }

    private void awaitLoadedLocked() {
        while (!this.mLoaded) {
            try {
                wait();
            } catch (InterruptedException unused) {
            }
        }
    }

    @Override // android.content.SharedPreferences
    public Map<String, ?> getAll() {
        HashMap hashMap;
        synchronized (this) {
            awaitLoadedLocked();
            hashMap = new HashMap(this.mMap);
        }
        return hashMap;
    }

    public String getString(String str, String str2) {
        synchronized (this) {
            awaitLoadedLocked();
            String str3 = (String) this.mMap.get(str);
            if (str3 != null) {
                str2 = str3;
            }
        }
        return str2;
    }

    @Override // android.content.SharedPreferences
    public Set<String> getStringSet(String str, Set<String> set) {
        synchronized (this) {
            awaitLoadedLocked();
            Set<String> set2 = (Set) this.mMap.get(str);
            if (set2 != null) {
                set = set2;
            }
        }
        return set;
    }

    public int getInt(String str, int i) {
        synchronized (this) {
            awaitLoadedLocked();
            Integer num = (Integer) this.mMap.get(str);
            if (num != null) {
                i = num.intValue();
            }
        }
        return i;
    }

    public long getLong(String str, long j) {
        synchronized (this) {
            awaitLoadedLocked();
            Long l = (Long) this.mMap.get(str);
            if (l != null) {
                j = l.longValue();
            }
        }
        return j;
    }

    public float getFloat(String str, float f) {
        synchronized (this) {
            awaitLoadedLocked();
            Float f2 = (Float) this.mMap.get(str);
            if (f2 != null) {
                f = f2.floatValue();
            }
        }
        return f;
    }

    public boolean getBoolean(String str, boolean z) {
        synchronized (this) {
            awaitLoadedLocked();
            Boolean bool = (Boolean) this.mMap.get(str);
            if (bool != null) {
                z = bool.booleanValue();
            }
        }
        return z;
    }

    public boolean contains(String str) {
        boolean containsKey;
        synchronized (this) {
            awaitLoadedLocked();
            containsKey = this.mMap.containsKey(str);
        }
        return containsKey;
    }

    @Deprecated
    public SharedPreferences.Editor edit() {
        throw new UnsupportedOperationException("read-only implementation");
    }

    public void registerOnSharedPreferenceChangeListener(SharedPreferences.OnSharedPreferenceChangeListener onSharedPreferenceChangeListener) {
        if (onSharedPreferenceChangeListener != null) {
            synchronized (this) {
                if (this.mListeners.put(onSharedPreferenceChangeListener, sContent) == null) {
                    tryRegisterWatcher();
                }
            }
            return;
        }
        throw new IllegalArgumentException("listener cannot be null");
    }

    public void unregisterOnSharedPreferenceChangeListener(SharedPreferences.OnSharedPreferenceChangeListener onSharedPreferenceChangeListener) {
        synchronized (this) {
            if (this.mListeners.remove(onSharedPreferenceChangeListener) != null && this.mListeners.isEmpty()) {
                tryUnregisterWatcher();
            }
        }
    }

    /* access modifiers changed from: private */
    public static class PrefsData {
        private byte[] mHash;
        public final XSharedPreferences mPrefs;
        private long mSize;

        public PrefsData(XSharedPreferences xSharedPreferences) {
            this.mPrefs = xSharedPreferences;
            this.mSize = XSharedPreferences.tryGetFileSize(xSharedPreferences.mFilename);
            this.mHash = XSharedPreferences.tryGetFileHash(xSharedPreferences.mFilename);
        }

        public boolean hasChanged() {
            long tryGetFileSize = XSharedPreferences.tryGetFileSize(this.mPrefs.mFilename);
            if (tryGetFileSize < 1) {
                return false;
            }
            if (tryGetFileSize != this.mSize) {
                this.mSize = tryGetFileSize;
                this.mHash = XSharedPreferences.tryGetFileHash(this.mPrefs.mFilename);
                return true;
            }
            byte[] tryGetFileHash = XSharedPreferences.tryGetFileHash(this.mPrefs.mFilename);
            if (Arrays.equals(tryGetFileHash, this.mHash)) {
                return false;
            }
            this.mHash = tryGetFileHash;
            return true;
        }
    }
}
