package de.robv.android.xposed;

import android.app.ActivityThread;
import android.content.res.Resources;
import android.content.res.TypedArray;
import android.util.Log;
import de.robv.android.xposed.XC_MethodHook;
import de.robv.android.xposed.callbacks.XC_InitPackageResources;
import de.robv.android.xposed.callbacks.XC_LoadPackage;
import java.lang.reflect.Constructor;
import java.lang.reflect.Executable;
import java.lang.reflect.InvocationTargetException;
import java.lang.reflect.Member;
import java.lang.reflect.Method;
import java.lang.reflect.Modifier;
import java.lang.reflect.Proxy;
import java.util.Arrays;
import java.util.HashSet;
import java.util.Objects;
import java.util.Set;
import java.util.concurrent.CopyOnWriteArraySet;
import org.lsposed.lspd.nativebridge.HookBridge;
import org.lsposed.lspd.nativebridge.ResourcesHook;

public final class XposedBridge {
    static final /* synthetic */ boolean $assertionsDisabled = false;
    public static final ClassLoader BOOTCLASSLOADER = XposedBridge.class.getClassLoader();
    private static final Object[] EMPTY_ARRAY = new Object[0];
    public static final String TAG = "LSPosed-Bridge";
    @Deprecated
    public static int XPOSED_BRIDGE_VERSION = 0;
    private static final String castException = "Return value's type from hook callback does not match the hooked method";
    public static volatile ClassLoader dummyClassLoader = null;
    private static final Method getCause;
    static final CopyOnWriteArraySet<XC_InitPackageResources> sInitPackageResourcesCallbacks = new CopyOnWriteArraySet<>();
    public static final CopyOnWriteArraySet<XC_LoadPackage> sLoadedPackageCallbacks = new CopyOnWriteArraySet<>();

    public static int getXposedVersion() {
        return 93;
    }

    static {
        Method method = null;
        try {
            method = InvocationTargetException.class.getMethod("getCause", new Class[0]);
        } catch (Throwable unused) {
        }
        getCause = method;
    }

    private XposedBridge() {
    }

    public static void initXResources() {
        Class<?> cls;
        Object newInstance;
        if (dummyClassLoader == null) {
            try {
                Resources system = Resources.getSystem();
                Class<?> cls2 = system.getClass();
                try {
                    TypedArray obtainTypedArray = system.obtainTypedArray(system.getIdentifier("preloaded_drawables", "array", "android"));
                    cls = obtainTypedArray.getClass();
                    obtainTypedArray.recycle();
                } catch (NullPointerException unused) {
                    try {
                        newInstance = XposedHelpers.newInstance(ActivityThread.class, new Object[0]);
                        newInstance = null;
                        TypedArray obtainTypedArray2 = system.obtainTypedArray(system.getIdentifier("preloaded_drawables", "array", "android"));
                        cls = obtainTypedArray2.getClass();
                        obtainTypedArray2.recycle();
                    } catch (Resources.NotFoundException e) {
                        log(e);
                    }
                } finally {
                    XposedHelpers.setStaticObjectField(ActivityThread.class, "sCurrentActivityThread", newInstance);
                }
                ResourcesHook.makeInheritable(cls2);
                ResourcesHook.makeInheritable(cls);
                ClassLoader classLoader = XposedBridge.class.getClassLoader();
                dummyClassLoader = ResourcesHook.buildDummyClassLoader(classLoader.getParent(), cls2.getName(), cls.getName());
                dummyClassLoader.loadClass("xposed.dummy.XResourcesSuperClass");
                dummyClassLoader.loadClass("xposed.dummy.XTypedArraySuperClass");
                XposedHelpers.setObjectField(classLoader, "parent", dummyClassLoader);
            } catch (Throwable th) {
                log(th);
                XposedInit.disableResources = true;
            }
        }
    }

    public static synchronized void log(String str) {
        synchronized (XposedBridge.class) {
            Log.i(TAG, str);
        }
    }

    public static synchronized void log(Throwable th) {
        synchronized (XposedBridge.class) {
            Log.e(TAG, Log.getStackTraceString(th));
        }
    }

    public static void deoptimizeMethod(Member member) {
        if (!(member instanceof Executable)) {
            throw new IllegalArgumentException("Only methods and constructors can be deoptimized: " + member);
        } else if (Modifier.isAbstract(member.getModifiers())) {
            throw new IllegalArgumentException("Cannot deoptimize abstract methods: " + member);
        } else if (!Proxy.isProxyClass(member.getDeclaringClass())) {
            HookBridge.deoptimizeMethod((Executable) member);
        } else {
            throw new IllegalArgumentException("Cannot deoptimize methods from proxy class: " + member);
        }
    }

    public static XC_MethodHook.Unhook hookMethod(Member member, XC_MethodHook xC_MethodHook) {
        if (!(member instanceof Executable)) {
            throw new IllegalArgumentException("Only methods and constructors can be hooked: " + member);
        } else if (Modifier.isAbstract(member.getModifiers())) {
            throw new IllegalArgumentException("Cannot hook abstract methods: " + member);
        } else if (member.getDeclaringClass().getClassLoader() == XposedBridge.class.getClassLoader()) {
            throw new IllegalArgumentException("Do not allow hooking inner methods");
        } else if (member.getDeclaringClass() == Method.class && member.getName().equals("invoke")) {
            throw new IllegalArgumentException("Cannot hook Method.invoke");
        } else if (xC_MethodHook == null) {
            throw new IllegalArgumentException("callback should not be null!");
        } else if (!HookBridge.hookMethod((Executable) member, AdditionalHookInfo.class, xC_MethodHook.priority, xC_MethodHook)) {
            log("Failed to hook " + member);
            return null;
        } else {
            Objects.requireNonNull(xC_MethodHook);
            return new XC_MethodHook.Unhook(member);
        }
    }

    @Deprecated
    public static void unhookMethod(Member member, XC_MethodHook xC_MethodHook) {
        if (member instanceof Executable) {
            HookBridge.unhookMethod((Executable) member, xC_MethodHook);
        }
    }

    public static Set<XC_MethodHook.Unhook> hookAllMethods(Class<?> cls, String str, XC_MethodHook xC_MethodHook) {
        HashSet hashSet = new HashSet();
        Method[] declaredMethods = cls.getDeclaredMethods();
        for (Method method : declaredMethods) {
            if (method.getName().equals(str)) {
                hashSet.add(hookMethod(method, xC_MethodHook));
            }
        }
        return hashSet;
    }

    public static Set<XC_MethodHook.Unhook> hookAllConstructors(Class<?> cls, XC_MethodHook xC_MethodHook) {
        HashSet hashSet = new HashSet();
        for (Constructor<?> constructor : cls.getDeclaredConstructors()) {
            hashSet.add(hookMethod(constructor, xC_MethodHook));
        }
        return hashSet;
    }

    public static void hookLoadPackage(XC_LoadPackage xC_LoadPackage) {
        CopyOnWriteArraySet<XC_LoadPackage> copyOnWriteArraySet = sLoadedPackageCallbacks;
        synchronized (copyOnWriteArraySet) {
            copyOnWriteArraySet.add(xC_LoadPackage);
        }
    }

    public static void hookInitPackageResources(XC_InitPackageResources xC_InitPackageResources) {
        CopyOnWriteArraySet<XC_InitPackageResources> copyOnWriteArraySet = sInitPackageResourcesCallbacks;
        synchronized (copyOnWriteArraySet) {
            copyOnWriteArraySet.add(xC_InitPackageResources);
        }
    }

    public static Object invokeOriginalMethod(Member member, Object obj, Object[] objArr) throws Throwable {
        if (objArr == null) {
            objArr = EMPTY_ARRAY;
        }
        if (member instanceof Executable) {
            return HookBridge.invokeOriginalMethod((Executable) member, obj, objArr);
        }
        throw new IllegalArgumentException("method must be of type Method or Constructor");
    }

    public static final class CopyOnWriteSortedSet<E> {
        private volatile transient Object[] elements = XposedBridge.EMPTY_ARRAY;

        public synchronized boolean add(E e) {
            if (indexOf(e) >= 0) {
                return false;
            }
            Object[] objArr = new Object[(this.elements.length + 1)];
            System.arraycopy(this.elements, 0, objArr, 0, this.elements.length);
            objArr[this.elements.length] = e;
            Arrays.sort(objArr);
            this.elements = objArr;
            return true;
        }

        public synchronized boolean remove(E e) {
            int indexOf = indexOf(e);
            if (indexOf == -1) {
                return false;
            }
            Object[] objArr = new Object[(this.elements.length - 1)];
            System.arraycopy(this.elements, 0, objArr, 0, indexOf);
            System.arraycopy(this.elements, indexOf + 1, objArr, indexOf, (this.elements.length - indexOf) - 1);
            this.elements = objArr;
            return true;
        }

        private int indexOf(Object obj) {
            for (int i = 0; i < this.elements.length; i++) {
                if (obj.equals(this.elements[i])) {
                    return i;
                }
            }
            return -1;
        }

        public Object[] getSnapshot() {
            return this.elements;
        }

        public <T> T[] getSnapshot(T[] tArr) {
            Object[] snapshot = getSnapshot();
            return (T[]) Arrays.copyOf(snapshot, snapshot.length, tArr.getClass());
        }

        public synchronized void clear() {
            this.elements = XposedBridge.EMPTY_ARRAY;
        }
    }

    public static class AdditionalHookInfo {
        private final Object params;

        private AdditionalHookInfo(Executable executable) {
            this.params = new Object[]{executable, executable instanceof Method ? ((Method) executable).getReturnType() : null, Boolean.valueOf(Modifier.isStatic(executable.getModifiers()))};
        }

        public Object callback(Object[] objArr) throws Throwable {
            XC_MethodHook.MethodHookParam methodHookParam = new XC_MethodHook.MethodHookParam();
            Object[] objArr2 = (Object[]) this.params;
            Executable executable = (Executable) objArr2[0];
            Class cls = (Class) objArr2[1];
            methodHookParam.method = executable;
            if (((Boolean) objArr2[2]).booleanValue()) {
                methodHookParam.thisObject = null;
                methodHookParam.args = objArr;
            } else {
                methodHookParam.thisObject = objArr[0];
                methodHookParam.args = new Object[(objArr.length - 1)];
                int i = 0;
                while (i < objArr.length - 1) {
                    int i2 = i + 1;
                    methodHookParam.args[i] = objArr[i2];
                    i = i2;
                }
            }
            Object[] callbackSnapshot = HookBridge.callbackSnapshot(executable);
            if (callbackSnapshot == null || callbackSnapshot.length == 0) {
                try {
                    return HookBridge.invokeOriginalMethod(executable, methodHookParam.thisObject, methodHookParam.args);
                } catch (InvocationTargetException e) {
                    throw ((Throwable) HookBridge.invokeOriginalMethod(XposedBridge.getCause, e, new Object[0]));
                }
            } else {
                int i3 = 0;
                while (true) {
                    try {
                        ((XC_MethodHook) callbackSnapshot[i3]).beforeHookedMethod(methodHookParam);
                        if (methodHookParam.returnEarly) {
                            i3++;
                            break;
                        }
                    } catch (Throwable th) {
                        XposedBridge.log(th);
                        methodHookParam.setResult(null);
                        methodHookParam.returnEarly = false;
                    }
                    i3++;
                    if (i3 >= callbackSnapshot.length) {
                        break;
                    }
                }
                if (!methodHookParam.returnEarly) {
                    try {
                        methodHookParam.setResult(HookBridge.invokeOriginalMethod(executable, methodHookParam.thisObject, methodHookParam.args));
                    } catch (InvocationTargetException e2) {
                        methodHookParam.setThrowable((Throwable) HookBridge.invokeOriginalMethod(XposedBridge.getCause, e2, new Object[0]));
                    }
                }
                int i4 = i3 - 1;
                do {
                    Object result = methodHookParam.getResult();
                    Throwable throwable = methodHookParam.getThrowable();
                    try {
                        ((XC_MethodHook) callbackSnapshot[i4]).afterHookedMethod(methodHookParam);
                    } catch (Throwable th2) {
                        XposedBridge.log(th2);
                        if (throwable == null) {
                            methodHookParam.setResult(result);
                        } else {
                            methodHookParam.setThrowable(throwable);
                        }
                    }
                    i4--;
                } while (i4 >= 0);
                if (!methodHookParam.hasThrowable()) {
                    Object result2 = methodHookParam.getResult();
                    if (cls == null || cls.isPrimitive() || HookBridge.instanceOf(result2, cls)) {
                        return result2;
                    }
                    throw new ClassCastException(XposedBridge.castException);
                }
                throw methodHookParam.getThrowable();
            }
        }
    }
}
