package de.robv.android.xposed.callbacks;

import android.os.Bundle;
import de.robv.android.xposed.XposedBridge;
import de.robv.android.xposed.callbacks.XC_LoadPackage;
import java.io.Serializable;
import org.lsposed.lspd.deopt.PrebuiltMethodsDeopter;

public abstract class XCallback {
    public static final int PRIORITY_DEFAULT = 50;
    public static final int PRIORITY_HIGHEST = 10000;
    public static final int PRIORITY_LOWEST = -10000;
    public final int priority;

    /* access modifiers changed from: protected */
    public void call(Param param) throws Throwable {
    }

    @Deprecated
    public XCallback() {
        this.priority = 50;
    }

    public XCallback(int i) {
        this.priority = i;
    }

    public static abstract class Param {
        public final XCallback[] callbacks;
        private Bundle extra;

        @Deprecated
        protected Param() {
            this.callbacks = null;
        }

        protected Param(XCallback[] xCallbackArr) {
            this.callbacks = xCallbackArr;
        }

        public synchronized Bundle getExtra() {
            if (this.extra == null) {
                this.extra = new Bundle();
            }
            return this.extra;
        }

        public Object getObjectExtra(String str) {
            Serializable serializable = getExtra().getSerializable(str);
            if (serializable instanceof SerializeWrapper) {
                return ((SerializeWrapper) serializable).object;
            }
            return null;
        }

        public void setObjectExtra(String str, Object obj) {
            getExtra().putSerializable(str, new SerializeWrapper(obj));
        }

        private static class SerializeWrapper implements Serializable {
            private static final long serialVersionUID = 1;
            private final Object object;

            public SerializeWrapper(Object obj) {
                this.object = obj;
            }
        }
    }

    public static void callAll(Param param) {
        if (param instanceof XC_LoadPackage.LoadPackageParam) {
            XC_LoadPackage.LoadPackageParam loadPackageParam = (XC_LoadPackage.LoadPackageParam) param;
            PrebuiltMethodsDeopter.deoptMethods(loadPackageParam.packageName, loadPackageParam.classLoader);
        }
        if (param.callbacks != null) {
            for (int i = 0; i < param.callbacks.length; i++) {
                try {
                    param.callbacks[i].call(param);
                } catch (Throwable th) {
                    XposedBridge.log(th);
                }
            }
            return;
        }
        throw new IllegalStateException("This object was not created for use with callAll");
    }
}
