package org.apache.commons.lang3.compare;

import java.util.function.Predicate;

public class ComparableUtils {

    public static class ComparableCheckBuilder<A extends Comparable<A>> {
        private final A a;

        private ComparableCheckBuilder(A a2) {
            this.a = a2;
        }

        public boolean between(A a2, A a3) {
            return betweenOrdered(a2, a3) || betweenOrdered(a3, a2);
        }

        public boolean betweenExclusive(A a2, A a3) {
            return betweenOrderedExclusive(a2, a3) || betweenOrderedExclusive(a3, a2);
        }

        private boolean betweenOrdered(A a2, A a3) {
            return greaterThanOrEqualTo(a2) && lessThanOrEqualTo(a3);
        }

        private boolean betweenOrderedExclusive(A a2, A a3) {
            return greaterThan(a2) && lessThan(a3);
        }

        public boolean equalTo(A a2) {
            return this.a.compareTo(a2) == 0;
        }

        public boolean greaterThan(A a2) {
            return this.a.compareTo(a2) > 0;
        }

        public boolean greaterThanOrEqualTo(A a2) {
            return this.a.compareTo(a2) >= 0;
        }

        public boolean lessThan(A a2) {
            return this.a.compareTo(a2) < 0;
        }

        public boolean lessThanOrEqualTo(A a2) {
            return this.a.compareTo(a2) <= 0;
        }
    }

    public static <A extends Comparable<A>> Predicate<A> between(A a, A a2) {
        return new ComparableUtils$$ExternalSyntheticLambda5(a, a2);
    }

    public static <A extends Comparable<A>> Predicate<A> betweenExclusive(A a, A a2) {
        return new ComparableUtils$$ExternalSyntheticLambda0(a, a2);
    }

    public static <A extends Comparable<A>> Predicate<A> ge(A a) {
        return new ComparableUtils$$ExternalSyntheticLambda2(a);
    }

    static /* synthetic */ boolean lambda$ge$2(Comparable comparable, Comparable comparable2) {
        return is(comparable2).greaterThanOrEqualTo(comparable);
    }

    public static <A extends Comparable<A>> Predicate<A> gt(A a) {
        return new ComparableUtils$$ExternalSyntheticLambda4(a);
    }

    static /* synthetic */ boolean lambda$gt$3(Comparable comparable, Comparable comparable2) {
        return is(comparable2).greaterThan(comparable);
    }

    public static <A extends Comparable<A>> ComparableCheckBuilder<A> is(A a) {
        return new ComparableCheckBuilder<>(a);
    }

    static /* synthetic */ boolean lambda$le$4(Comparable comparable, Comparable comparable2) {
        return is(comparable2).lessThanOrEqualTo(comparable);
    }

    public static <A extends Comparable<A>> Predicate<A> le(A a) {
        return new ComparableUtils$$ExternalSyntheticLambda3(a);
    }

    public static <A extends Comparable<A>> Predicate<A> lt(A a) {
        return new ComparableUtils$$ExternalSyntheticLambda1(a);
    }

    private ComparableUtils() {
    }
}
