package org.apache.commons.lang3.function;

import java.lang.Throwable;
import java.util.Objects;

@FunctionalInterface
public interface FailableBiPredicate<T, U, E extends Throwable> {
    public static final FailableBiPredicate FALSE = new FailableBiPredicate$$ExternalSyntheticLambda2();
    public static final FailableBiPredicate TRUE = new FailableBiPredicate$$ExternalSyntheticLambda3();

    static /* synthetic */ default boolean lambda$static$0(Object obj, Object obj2) throws Throwable {
        return false;
    }

    static /* synthetic */ default boolean lambda$static$1(Object obj, Object obj2) throws Throwable {
        return true;
    }

    boolean test(T t, U u) throws Throwable;

    static default <T, U, E extends Throwable> FailableBiPredicate<T, U, E> falsePredicate() {
        return FALSE;
    }

    static default <T, U, E extends Throwable> FailableBiPredicate<T, U, E> truePredicate() {
        return TRUE;
    }

    default FailableBiPredicate<T, U, E> and(FailableBiPredicate<? super T, ? super U, E> failableBiPredicate) {
        Objects.requireNonNull(failableBiPredicate);
        return new FailableBiPredicate$$ExternalSyntheticLambda1(this, failableBiPredicate);
    }

    static /* synthetic */ default boolean lambda$and$2(FailableBiPredicate _this, FailableBiPredicate failableBiPredicate, Object obj, Object obj2) throws Throwable {
        return _this.test(obj, obj2) && failableBiPredicate.test(obj, obj2);
    }

    static /* synthetic */ default boolean lambda$negate$3(FailableBiPredicate _this, Object obj, Object obj2) throws Throwable {
        return !_this.test(obj, obj2);
    }

    default FailableBiPredicate<T, U, E> negate() {
        return new FailableBiPredicate$$ExternalSyntheticLambda4(this);
    }

    default FailableBiPredicate<T, U, E> or(FailableBiPredicate<? super T, ? super U, E> failableBiPredicate) {
        Objects.requireNonNull(failableBiPredicate);
        return new FailableBiPredicate$$ExternalSyntheticLambda0(this, failableBiPredicate);
    }

    static /* synthetic */ default boolean lambda$or$4(FailableBiPredicate _this, FailableBiPredicate failableBiPredicate, Object obj, Object obj2) throws Throwable {
        return _this.test(obj, obj2) || failableBiPredicate.test(obj, obj2);
    }
}
