package org.apache.commons.lang3.function;

import java.lang.Throwable;
import java.util.Objects;

@FunctionalInterface
public interface FailableFunction<T, R, E extends Throwable> {
    public static final FailableFunction NOP = new FailableFunction$$ExternalSyntheticLambda2();

    static /* synthetic */ default Object lambda$identity$1(Object obj) throws Throwable {
        return obj;
    }

    static /* synthetic */ default Object lambda$static$0(Object obj) throws Throwable {
        return null;
    }

    R apply(T t) throws Throwable;

    static default <T, E extends Throwable> FailableFunction<T, T, E> identity() {
        return new FailableFunction$$ExternalSyntheticLambda0();
    }

    static default <T, R, E extends Throwable> FailableFunction<T, R, E> nop() {
        return NOP;
    }

    default <V> FailableFunction<T, V, E> andThen(FailableFunction<? super R, ? extends V, E> failableFunction) {
        Objects.requireNonNull(failableFunction);
        return new FailableFunction$$ExternalSyntheticLambda1(this, failableFunction);
    }

    default <V> FailableFunction<V, R, E> compose(FailableFunction<? super V, ? extends T, E> failableFunction) {
        Objects.requireNonNull(failableFunction);
        return new FailableFunction$$ExternalSyntheticLambda3(this, failableFunction);
    }
}
