package org.apache.commons.lang3.math;

import java.lang.reflect.Array;
import java.math.BigDecimal;
import java.math.BigInteger;
import java.math.RoundingMode;
import org.apache.commons.lang3.StringUtils;
import org.apache.commons.lang3.Validate;

public class NumberUtils {
    public static final Byte BYTE_MINUS_ONE = (byte) -1;
    public static final Byte BYTE_ONE = (byte) 1;
    public static final Byte BYTE_ZERO = (byte) 0;
    public static final Double DOUBLE_MINUS_ONE = Double.valueOf(-1.0d);
    public static final Double DOUBLE_ONE = Double.valueOf(1.0d);
    public static final Double DOUBLE_ZERO = Double.valueOf(0.0d);
    public static final Float FLOAT_MINUS_ONE = Float.valueOf(-1.0f);
    public static final Float FLOAT_ONE = Float.valueOf(1.0f);
    public static final Float FLOAT_ZERO = Float.valueOf(0.0f);
    public static final Integer INTEGER_MINUS_ONE = -1;
    public static final Integer INTEGER_ONE = 1;
    public static final Integer INTEGER_TWO = 2;
    public static final Integer INTEGER_ZERO = 0;
    public static final Long LONG_INT_MAX_VALUE = 2147483647L;
    public static final Long LONG_INT_MIN_VALUE = -2147483648L;
    public static final Long LONG_MINUS_ONE = -1L;
    public static final Long LONG_ONE = 1L;
    public static final Long LONG_ZERO = 0L;
    public static final Short SHORT_MINUS_ONE = -1;
    public static final Short SHORT_ONE = 1;
    public static final Short SHORT_ZERO = 0;

    public static int compare(byte b, byte b2) {
        return b - b2;
    }

    public static int compare(int i, int i2) {
        if (i == i2) {
            return 0;
        }
        return i < i2 ? -1 : 1;
    }

    public static int compare(long j, long j2) {
        int i = (j > j2 ? 1 : (j == j2 ? 0 : -1));
        if (i == 0) {
            return 0;
        }
        return i < 0 ? -1 : 1;
    }

    public static int compare(short s, short s2) {
        if (s == s2) {
            return 0;
        }
        return s < s2 ? -1 : 1;
    }

    public static byte max(byte b, byte b2, byte b3) {
        if (b2 > b) {
            b = b2;
        }
        return b3 > b ? b3 : b;
    }

    public static int max(int i, int i2, int i3) {
        if (i2 > i) {
            i = i2;
        }
        return i3 > i ? i3 : i;
    }

    public static long max(long j, long j2, long j3) {
        if (j2 > j) {
            j = j2;
        }
        return j3 > j ? j3 : j;
    }

    public static short max(short s, short s2, short s3) {
        if (s2 > s) {
            s = s2;
        }
        return s3 > s ? s3 : s;
    }

    public static byte min(byte b, byte b2, byte b3) {
        if (b2 < b) {
            b = b2;
        }
        return b3 < b ? b3 : b;
    }

    public static int min(int i, int i2, int i3) {
        if (i2 < i) {
            i = i2;
        }
        return i3 < i ? i3 : i;
    }

    public static long min(long j, long j2, long j3) {
        if (j2 < j) {
            j = j2;
        }
        return j3 < j ? j3 : j;
    }

    public static short min(short s, short s2, short s3) {
        if (s2 < s) {
            s = s2;
        }
        return s3 < s ? s3 : s;
    }

    public static int toInt(String str) {
        return toInt(str, 0);
    }

    public static int toInt(String str, int i) {
        if (str == null) {
            return i;
        }
        try {
            return Integer.parseInt(str);
        } catch (NumberFormatException unused) {
            return i;
        }
    }

    public static long toLong(String str) {
        return toLong(str, 0);
    }

    public static long toLong(String str, long j) {
        if (str == null) {
            return j;
        }
        try {
            return Long.parseLong(str);
        } catch (NumberFormatException unused) {
            return j;
        }
    }

    public static float toFloat(String str) {
        return toFloat(str, 0.0f);
    }

    public static float toFloat(String str, float f) {
        if (str == null) {
            return f;
        }
        try {
            return Float.parseFloat(str);
        } catch (NumberFormatException unused) {
            return f;
        }
    }

    public static double toDouble(String str) {
        return toDouble(str, 0.0d);
    }

    public static double toDouble(String str, double d) {
        if (str == null) {
            return d;
        }
        try {
            return Double.parseDouble(str);
        } catch (NumberFormatException unused) {
            return d;
        }
    }

    public static double toDouble(BigDecimal bigDecimal) {
        return toDouble(bigDecimal, 0.0d);
    }

    public static double toDouble(BigDecimal bigDecimal, double d) {
        return bigDecimal == null ? d : bigDecimal.doubleValue();
    }

    public static byte toByte(String str) {
        return toByte(str, (byte) 0);
    }

    public static byte toByte(String str, byte b) {
        if (str == null) {
            return b;
        }
        try {
            return Byte.parseByte(str);
        } catch (NumberFormatException unused) {
            return b;
        }
    }

    public static short toShort(String str) {
        return toShort(str, 0);
    }

    public static short toShort(String str, short s) {
        if (str == null) {
            return s;
        }
        try {
            return Short.parseShort(str);
        } catch (NumberFormatException unused) {
            return s;
        }
    }

    public static BigDecimal toScaledBigDecimal(BigDecimal bigDecimal) {
        return toScaledBigDecimal(bigDecimal, INTEGER_TWO.intValue(), RoundingMode.HALF_EVEN);
    }

    public static BigDecimal toScaledBigDecimal(BigDecimal bigDecimal, int i, RoundingMode roundingMode) {
        if (bigDecimal == null) {
            return BigDecimal.ZERO;
        }
        if (roundingMode == null) {
            roundingMode = RoundingMode.HALF_EVEN;
        }
        return bigDecimal.setScale(i, roundingMode);
    }

    public static BigDecimal toScaledBigDecimal(Float f) {
        return toScaledBigDecimal(f, INTEGER_TWO.intValue(), RoundingMode.HALF_EVEN);
    }

    public static BigDecimal toScaledBigDecimal(Float f, int i, RoundingMode roundingMode) {
        if (f == null) {
            return BigDecimal.ZERO;
        }
        return toScaledBigDecimal(BigDecimal.valueOf((double) f.floatValue()), i, roundingMode);
    }

    public static BigDecimal toScaledBigDecimal(Double d) {
        return toScaledBigDecimal(d, INTEGER_TWO.intValue(), RoundingMode.HALF_EVEN);
    }

    public static BigDecimal toScaledBigDecimal(Double d, int i, RoundingMode roundingMode) {
        if (d == null) {
            return BigDecimal.ZERO;
        }
        return toScaledBigDecimal(BigDecimal.valueOf(d.doubleValue()), i, roundingMode);
    }

    public static BigDecimal toScaledBigDecimal(String str) {
        return toScaledBigDecimal(str, INTEGER_TWO.intValue(), RoundingMode.HALF_EVEN);
    }

    public static BigDecimal toScaledBigDecimal(String str, int i, RoundingMode roundingMode) {
        if (str == null) {
            return BigDecimal.ZERO;
        }
        return toScaledBigDecimal(createBigDecimal(str), i, roundingMode);
    }

    /* JADX DEBUG: Failed to insert an additional move for type inference into block B:120:0x01b5 */
    /* JADX DEBUG: Multi-variable search result rejected for r15v0, resolved type: java.lang.String */
    /* JADX DEBUG: Multi-variable search result rejected for r15v4, resolved type: java.lang.String */
    /* JADX WARN: Multi-variable type inference failed */
    /* JADX WARN: Type inference failed for: r15v8, types: [java.lang.Number, java.lang.Integer] */
    /* JADX WARNING: Can't wrap try/catch for region: R(11:(1:56)|57|(1:62)(1:61)|63|(5:65|(3:67|(2:69|(2:71|(1:73)))|(2:91|92)(3:85|86|87))|93|94|(1:100))|101|102|(1:108)|109|110|111) */
    /* JADX WARNING: Code restructure failed: missing block: B:114:0x01a7, code lost:
        throw new java.lang.NumberFormatException(r15 + " is not a valid number.");
     */
    /* JADX WARNING: Code restructure failed: missing block: B:125:0x01be, code lost:
        return createLong(r15);
     */
    /* JADX WARNING: Code restructure failed: missing block: B:128:0x01c3, code lost:
        return createBigInteger(r15);
     */
    /* JADX WARNING: Code restructure failed: missing block: B:74:0x011d, code lost:
        if (r4 == 'l') goto L_0x011f;
     */
    /* JADX WARNING: Failed to process nested try/catch */
    /* JADX WARNING: Missing exception handler attribute for start block: B:101:0x0177 */
    /* JADX WARNING: Missing exception handler attribute for start block: B:109:0x018c */
    /* JADX WARNING: Missing exception handler attribute for start block: B:123:0x01ba */
    public static Number createNumber(String str) {
        int i;
        String str2;
        String str3;
        String str4;
        String str5 = null;
        if (str == 0) {
            return null;
        }
        if (!StringUtils.isBlank(str)) {
            String[] strArr = {"0x", "0X", "-0x", "-0X", "#", "-#"};
            int length = str.length();
            char c = 0;
            int i2 = 0;
            while (true) {
                if (i2 >= 6) {
                    i = 0;
                    break;
                }
                String str6 = strArr[i2];
                if (str.startsWith(str6)) {
                    i = str6.length() + 0;
                    break;
                }
                i2++;
            }
            if (i > 0) {
                int i3 = i;
                while (i < length) {
                    c = str.charAt(i);
                    if (c != '0') {
                        break;
                    }
                    i3++;
                    i++;
                }
                int i4 = length - i3;
                if (i4 > 16 || (i4 == 16 && c > '7')) {
                    return createBigInteger(str);
                }
                if (i4 > 8 || (i4 == 8 && c > '7')) {
                    return createLong(str);
                }
                return createInteger(str);
            }
            int i5 = length - 1;
            char charAt = str.charAt(i5);
            int indexOf = str.indexOf(46);
            int indexOf2 = str.indexOf(101) + str.indexOf(69) + 1;
            if (indexOf > -1) {
                if (indexOf2 <= -1) {
                    str3 = str.substring(indexOf + 1);
                } else if (indexOf2 < indexOf || indexOf2 > length) {
                    throw new NumberFormatException(str + " is not a valid number.");
                } else {
                    str3 = str.substring(indexOf + 1, indexOf2);
                }
                str2 = getMantissa(str, indexOf);
            } else {
                if (indexOf2 <= -1) {
                    str4 = getMantissa(str);
                } else if (indexOf2 <= length) {
                    str4 = getMantissa(str, indexOf2);
                } else {
                    throw new NumberFormatException(str + " is not a valid number.");
                }
                str2 = str4;
                str3 = null;
            }
            if (Character.isDigit(charAt) || charAt == '.') {
                if (indexOf2 > -1 && indexOf2 < i5) {
                    str5 = str.substring(indexOf2 + 1);
                }
                if (str3 == null && str5 == null) {
                    str = createInteger(str);
                    return str;
                }
                if (isAllZeros(str2) && isAllZeros(str5)) {
                    c = 1;
                }
                try {
                    Float createFloat = createFloat(str);
                    Double createDouble = createDouble(str);
                    if (!createFloat.isInfinite() && ((createFloat.floatValue() != 0.0f || c != 0) && createFloat.toString().equals(createDouble.toString()))) {
                        return createFloat;
                    }
                    if (!createDouble.isInfinite() && !(createDouble.doubleValue() == 0.0d && c == 0)) {
                        BigDecimal createBigDecimal = createBigDecimal(str);
                        return createBigDecimal.compareTo(BigDecimal.valueOf(createDouble.doubleValue())) == 0 ? createDouble : createBigDecimal;
                    }
                    return createBigDecimal(str);
                } catch (NumberFormatException unused) {
                }
            } else {
                if (indexOf2 > -1 && indexOf2 < i5) {
                    str5 = str.substring(indexOf2 + 1, i5);
                }
                String substring = str.substring(0, i5);
                boolean z = isAllZeros(str2) && isAllZeros(str5);
                if (charAt != 'D') {
                    if (charAt != 'F') {
                        if (charAt != 'L') {
                            if (charAt != 'd') {
                                if (charAt != 'f') {
                                }
                            }
                        }
                        if (str3 == null && str5 == null && ((!substring.isEmpty() && substring.charAt(0) == '-' && isDigits(substring.substring(1))) || isDigits(substring))) {
                            try {
                                return createLong(substring);
                            } catch (NumberFormatException unused2) {
                                return createBigInteger(substring);
                            }
                        } else {
                            throw new NumberFormatException(str + " is not a valid number.");
                        }
                    }
                    Float createFloat2 = createFloat(str);
                    if (!createFloat2.isInfinite() && (createFloat2.floatValue() != 0.0f || z)) {
                        return createFloat2;
                    }
                }
                Double createDouble2 = createDouble(str);
                if (!createDouble2.isInfinite() && (createDouble2.doubleValue() != 0.0d || z)) {
                    return createDouble2;
                }
                return createBigDecimal(substring);
            }
        } else {
            throw new NumberFormatException("A blank string is not a valid number");
        }
    }

    private static String getMantissa(String str) {
        return getMantissa(str, str.length());
    }

    private static String getMantissa(String str, int i) {
        char charAt = str.charAt(0);
        return charAt == '-' || charAt == '+' ? str.substring(1, i) : str.substring(0, i);
    }

    private static boolean isAllZeros(String str) {
        if (str == null) {
            return true;
        }
        for (int length = str.length() - 1; length >= 0; length--) {
            if (str.charAt(length) != '0') {
                return false;
            }
        }
        return !str.isEmpty();
    }

    public static Float createFloat(String str) {
        if (str == null) {
            return null;
        }
        return Float.valueOf(str);
    }

    public static Double createDouble(String str) {
        if (str == null) {
            return null;
        }
        return Double.valueOf(str);
    }

    public static Integer createInteger(String str) {
        if (str == null) {
            return null;
        }
        return Integer.decode(str);
    }

    public static Long createLong(String str) {
        if (str == null) {
            return null;
        }
        return Long.decode(str);
    }

    /* JADX DEBUG: Multi-variable search result rejected for r5v0, resolved type: java.lang.String */
    /* JADX WARN: Multi-variable type inference failed */
    /* JADX WARN: Type inference failed for: r0v1, types: [int, boolean] */
    /* JADX WARNING: Unknown variable types count: 1 */
    public static BigInteger createBigInteger(String str) {
        int i;
        int i2;
        if (str == 0) {
            return null;
        }
        ?? startsWith = str.startsWith("-");
        int i3 = 16;
        if (str.startsWith("0x", startsWith == true ? 1 : 0) || str.startsWith("0X", startsWith)) {
            i = startsWith + 2;
        } else if (str.startsWith("#", startsWith)) {
            i = startsWith + 1;
        } else if (!str.startsWith("0", startsWith) || str.length() <= (i2 = startsWith + 1)) {
            i3 = 10;
            i = startsWith == true ? 1 : 0;
        } else {
            i3 = 8;
            i = i2;
        }
        BigInteger bigInteger = new BigInteger(str.substring(i), i3);
        return startsWith != 0 ? bigInteger.negate() : bigInteger;
    }

    public static BigDecimal createBigDecimal(String str) {
        if (str == null) {
            return null;
        }
        if (!StringUtils.isBlank(str)) {
            return new BigDecimal(str);
        }
        throw new NumberFormatException("A blank string is not a valid number");
    }

    public static long min(long... jArr) {
        validateArray(jArr);
        long j = jArr[0];
        for (int i = 1; i < jArr.length; i++) {
            long j2 = jArr[i];
            if (j2 < j) {
                j = j2;
            }
        }
        return j;
    }

    public static int min(int... iArr) {
        validateArray(iArr);
        int i = iArr[0];
        for (int i2 = 1; i2 < iArr.length; i2++) {
            int i3 = iArr[i2];
            if (i3 < i) {
                i = i3;
            }
        }
        return i;
    }

    public static short min(short... sArr) {
        validateArray(sArr);
        short s = sArr[0];
        for (int i = 1; i < sArr.length; i++) {
            short s2 = sArr[i];
            if (s2 < s) {
                s = s2;
            }
        }
        return s;
    }

    public static byte min(byte... bArr) {
        validateArray(bArr);
        byte b = bArr[0];
        for (int i = 1; i < bArr.length; i++) {
            byte b2 = bArr[i];
            if (b2 < b) {
                b = b2;
            }
        }
        return b;
    }

    public static double min(double... dArr) {
        validateArray(dArr);
        double d = dArr[0];
        for (int i = 1; i < dArr.length; i++) {
            if (Double.isNaN(dArr[i])) {
                return Double.NaN;
            }
            double d2 = dArr[i];
            if (d2 < d) {
                d = d2;
            }
        }
        return d;
    }

    public static float min(float... fArr) {
        validateArray(fArr);
        float f = fArr[0];
        for (int i = 1; i < fArr.length; i++) {
            if (Float.isNaN(fArr[i])) {
                return Float.NaN;
            }
            float f2 = fArr[i];
            if (f2 < f) {
                f = f2;
            }
        }
        return f;
    }

    public static long max(long... jArr) {
        validateArray(jArr);
        long j = jArr[0];
        for (int i = 1; i < jArr.length; i++) {
            long j2 = jArr[i];
            if (j2 > j) {
                j = j2;
            }
        }
        return j;
    }

    public static int max(int... iArr) {
        validateArray(iArr);
        int i = iArr[0];
        for (int i2 = 1; i2 < iArr.length; i2++) {
            int i3 = iArr[i2];
            if (i3 > i) {
                i = i3;
            }
        }
        return i;
    }

    public static short max(short... sArr) {
        validateArray(sArr);
        short s = sArr[0];
        for (int i = 1; i < sArr.length; i++) {
            short s2 = sArr[i];
            if (s2 > s) {
                s = s2;
            }
        }
        return s;
    }

    public static byte max(byte... bArr) {
        validateArray(bArr);
        byte b = bArr[0];
        for (int i = 1; i < bArr.length; i++) {
            byte b2 = bArr[i];
            if (b2 > b) {
                b = b2;
            }
        }
        return b;
    }

    public static double max(double... dArr) {
        validateArray(dArr);
        double d = dArr[0];
        for (int i = 1; i < dArr.length; i++) {
            if (Double.isNaN(dArr[i])) {
                return Double.NaN;
            }
            double d2 = dArr[i];
            if (d2 > d) {
                d = d2;
            }
        }
        return d;
    }

    public static float max(float... fArr) {
        validateArray(fArr);
        float f = fArr[0];
        for (int i = 1; i < fArr.length; i++) {
            if (Float.isNaN(fArr[i])) {
                return Float.NaN;
            }
            float f2 = fArr[i];
            if (f2 > f) {
                f = f2;
            }
        }
        return f;
    }

    private static void validateArray(Object obj) {
        Validate.notNull(obj, "array", new Object[0]);
        Validate.isTrue(Array.getLength(obj) != 0, "Array cannot be empty.", new Object[0]);
    }

    public static double min(double d, double d2, double d3) {
        return Math.min(Math.min(d, d2), d3);
    }

    public static float min(float f, float f2, float f3) {
        return Math.min(Math.min(f, f2), f3);
    }

    public static double max(double d, double d2, double d3) {
        return Math.max(Math.max(d, d2), d3);
    }

    public static float max(float f, float f2, float f3) {
        return Math.max(Math.max(f, f2), f3);
    }

    public static boolean isDigits(String str) {
        return StringUtils.isNumeric(str);
    }

    @Deprecated
    public static boolean isNumber(String str) {
        return isCreatable(str);
    }

    /* JADX WARNING: Code restructure failed: missing block: B:135:?, code lost:
        return r6;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:136:?, code lost:
        return false;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:137:?, code lost:
        return false;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:138:?, code lost:
        return false;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:139:?, code lost:
        return false;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:140:?, code lost:
        return false;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:141:?, code lost:
        return r6;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:142:?, code lost:
        return false;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:143:?, code lost:
        return false;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:55:0x0090, code lost:
        if (r3 >= r0.length) goto L_0x00ca;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:56:0x0092, code lost:
        r0 = r0[r3];
     */
    /* JADX WARNING: Code restructure failed: missing block: B:57:0x0094, code lost:
        if (r0 < '0') goto L_0x0099;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:58:0x0096, code lost:
        if (r0 > '9') goto L_0x0099;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:59:0x0098, code lost:
        return r6;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:60:0x0099, code lost:
        if (r0 == 'e') goto L_?;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:61:0x009b, code lost:
        if (r0 != 'E') goto L_0x009e;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:62:0x009e, code lost:
        if (r0 != '.') goto L_0x00a7;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:63:0x00a0, code lost:
        if (r15 != false) goto L_0x00a6;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:64:0x00a2, code lost:
        if (r14 == false) goto L_0x00a5;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:65:0x00a5, code lost:
        return r13;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:66:0x00a6, code lost:
        return false;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:67:0x00a7, code lost:
        if (r7 != false) goto L_0x00b8;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:69:0x00ab, code lost:
        if (r0 == 'd') goto L_0x00b7;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:71:0x00af, code lost:
        if (r0 == 'D') goto L_0x00b7;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:72:0x00b1, code lost:
        if (r0 == 'f') goto L_0x00b7;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:74:0x00b5, code lost:
        if (r0 != 'F') goto L_0x00b8;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:75:0x00b7, code lost:
        return r13;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:77:0x00ba, code lost:
        if (r0 == 'l') goto L_0x00c2;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:79:0x00be, code lost:
        if (r0 != 'L') goto L_0x00c1;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:80:0x00c1, code lost:
        return false;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:81:0x00c2, code lost:
        if (r13 == false) goto L_?;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:82:0x00c4, code lost:
        if (r14 != false) goto L_?;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:83:0x00c6, code lost:
        if (r15 != false) goto L_?;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:85:0x00ca, code lost:
        if (r7 != false) goto L_?;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:86:0x00cc, code lost:
        if (r13 == false) goto L_?;
     */
    public static boolean isCreatable(String str) {
        if (StringUtils.isEmpty(str)) {
            return false;
        }
        char[] charArray = str.toCharArray();
        int length = charArray.length;
        char c = charArray[0];
        boolean z = true;
        int i = (c == '-' || c == '+') ? 1 : 0;
        int i2 = i + 1;
        if (length > i2 && charArray[i] == '0' && !StringUtils.contains(str, 46)) {
            char c2 = charArray[i2];
            if (c2 == 'x' || c2 == 'X') {
                int i3 = i + 2;
                if (i3 == length) {
                    return false;
                }
                while (i3 < charArray.length) {
                    char c3 = charArray[i3];
                    if ((c3 < '0' || c3 > '9') && ((c3 < 'a' || c3 > 'f') && (c3 < 'A' || c3 > 'F'))) {
                        return false;
                    }
                    i3++;
                }
                return true;
            } else if (Character.isDigit(c2)) {
                while (i2 < charArray.length) {
                    char c4 = charArray[i2];
                    if (c4 < '0' || c4 > '7') {
                        return false;
                    }
                    i2++;
                }
                return true;
            }
        }
        int i4 = length - 1;
        boolean z2 = false;
        boolean z3 = false;
        boolean z4 = false;
        boolean z5 = false;
        while (true) {
            if (i >= i4) {
                if (i >= i4 + 1 || !z2 || z3) {
                }
            }
            char c5 = charArray[i];
            if (c5 >= '0' && c5 <= '9') {
                z2 = false;
                z3 = true;
            } else if (c5 == '.') {
                if (z5 || z4) {
                    return false;
                }
                z5 = true;
            } else if (c5 == 'e' || c5 == 'E') {
                if (z4 || !z3) {
                    return false;
                }
                z2 = true;
                z4 = true;
            } else if ((c5 != '+' && c5 != '-') || !z2) {
                return false;
            } else {
                z2 = false;
                z3 = false;
            }
            i++;
            z = true;
        }
        return false;
    }

    public static boolean isParsable(String str) {
        if (StringUtils.isEmpty(str) || str.charAt(str.length() - 1) == '.') {
            return false;
        }
        if (str.charAt(0) != '-') {
            return withDecimalsParsing(str, 0);
        }
        if (str.length() == 1) {
            return false;
        }
        return withDecimalsParsing(str, 1);
    }

    private static boolean withDecimalsParsing(String str, int i) {
        int i2 = 0;
        while (i < str.length()) {
            boolean z = str.charAt(i) == '.';
            if (z) {
                i2++;
            }
            if (i2 > 1) {
                return false;
            }
            if (!z && !Character.isDigit(str.charAt(i))) {
                return false;
            }
            i++;
        }
        return true;
    }
}
