package org.apache.commons.lang3.time;

import java.util.Date;
import java.util.TimeZone;

/* access modifiers changed from: package-private */
public class GmtTimeZone extends TimeZone {
    private static final int HOURS_PER_DAY = 24;
    private static final int MILLISECONDS_PER_MINUTE = 60000;
    private static final int MINUTES_PER_HOUR = 60;
    static final long serialVersionUID = 1;
    private final int offset;
    private final String zoneId;

    public boolean inDaylightTime(Date date) {
        return false;
    }

    public boolean useDaylightTime() {
        return false;
    }

    GmtTimeZone(boolean z, int i, int i2) {
        if (i >= HOURS_PER_DAY) {
            throw new IllegalArgumentException(i + " hours out of range");
        } else if (i2 < MINUTES_PER_HOUR) {
            int i3 = ((i * MINUTES_PER_HOUR) + i2) * MILLISECONDS_PER_MINUTE;
            this.offset = z ? -i3 : i3;
            this.zoneId = twoDigits(twoDigits(new StringBuilder(9).append(TimeZones.GMT_ID).append(z ? '-' : '+'), i).append(':'), i2).toString();
        } else {
            throw new IllegalArgumentException(i2 + " minutes out of range");
        }
    }

    private static StringBuilder twoDigits(StringBuilder sb, int i) {
        return sb.append((char) ((i / 10) + 48)).append((char) ((i % 10) + 48));
    }

    public int getOffset(int i, int i2, int i3, int i4, int i5, int i6) {
        return this.offset;
    }

    public void setRawOffset(int i) {
        throw new UnsupportedOperationException();
    }

    public int getRawOffset() {
        return this.offset;
    }

    public String getID() {
        return this.zoneId;
    }

    public String toString() {
        return "[GmtTimeZone id=\"" + this.zoneId + "\",offset=" + this.offset + ']';
    }

    public int hashCode() {
        return this.offset;
    }

    public boolean equals(Object obj) {
        if ((obj instanceof GmtTimeZone) && this.zoneId == ((GmtTimeZone) obj).zoneId) {
            return true;
        }
        return false;
    }
}
