package org.lsposed.lspatch.loader;

import android.app.ActivityThread;
import android.app.LoadedApk;
import android.content.Context;
import android.content.pm.ApplicationInfo;
import android.content.res.CompatibilityInfo;
import android.os.Build;
import android.os.Process;
import android.system.Os;
import android.util.Log;
import com.google.gson.Gson;
import de.robv.android.xposed.XposedHelpers;
import hidden.HiddenApiBridge;
import java.io.BufferedReader;
import java.io.File;
import java.io.FileOutputStream;
import java.io.IOException;
import java.io.InputStream;
import java.io.InputStreamReader;
import java.io.Reader;
import java.lang.reflect.Field;
import java.nio.charset.StandardCharsets;
import java.nio.file.CopyOption;
import java.nio.file.Files;
import java.nio.file.LinkOption;
import java.nio.file.Path;
import java.nio.file.Paths;
import java.nio.file.attribute.FileAttribute;
import java.nio.file.attribute.PosixFilePermission;
import java.nio.file.attribute.PosixFilePermissions;
import java.util.ArrayList;
import java.util.Collections;
import java.util.Map;
import java.util.Set;
import java.util.zip.ZipFile;
import org.lsposed.lspatch.loader.util.FileUtils;
import org.lsposed.lspatch.loader.util.XLog;
import org.lsposed.lspatch.service.LocalApplicationService;
import org.lsposed.lspatch.service.RemoteApplicationService;
import org.lsposed.lspatch.share.Constants;
import org.lsposed.lspatch.share.PatchConfig;
import org.lsposed.lspd.core.Startup;
import org.lsposed.lspd.service.ILSPApplicationService;
import pxb.android.ResConst;

public class LSPApplication {
    private static final int FIRST_APP_ZYGOTE_ISOLATED_UID;
    private static final int PER_USER_RANGE;
    private static final String TAG;
    private static ActivityThread activityThread;
    private static LoadedApk appLoadedApk;
    private static PatchConfig config;
    private static LoadedApk stubLoadedApk;

    public static boolean isIsolated() {
        return Process.myUid() % PER_USER_RANGE >= FIRST_APP_ZYGOTE_ISOLATED_UID;
    }

    public static void onLoad() {
        ILSPApplicationService iLSPApplicationService;
        if (isIsolated()) {
            XLog.d(TAG, "Skip isolated process");
            return;
        }
        activityThread = ActivityThread.currentActivityThread();
        Context createLoadedApkWithContext = createLoadedApkWithContext();
        if (createLoadedApkWithContext == null) {
            XLog.e(TAG, "Error when creating context");
            return;
        }
        Log.d(TAG, "Initialize service client");
        if (config.useManager) {
            iLSPApplicationService = new RemoteApplicationService(createLoadedApkWithContext);
        } else {
            iLSPApplicationService = new LocalApplicationService(createLoadedApkWithContext);
        }
        disableProfile(createLoadedApkWithContext);
        Startup.initXposed(false, ActivityThread.currentProcessName(), iLSPApplicationService);
        Log.i(TAG, "Bootstrap Xposed");
        Startup.bootstrapXposed();
        Log.i(TAG, "Load modules");
        LSPLoader.initModules(appLoadedApk);
        Log.i(TAG, "Modules initialized");
        switchAllClassLoader();
        SigBypass.doSigBypass(createLoadedApkWithContext, config.sigBypassLevel);
        Log.i(TAG, "LSPatch bootstrap completed");
    }

    private static Context createLoadedApkWithContext() {
        try {
            Object objectField = XposedHelpers.getObjectField(activityThread, "mBoundApplication");
            stubLoadedApk = (LoadedApk) XposedHelpers.getObjectField(objectField, "info");
            ApplicationInfo applicationInfo = (ApplicationInfo) XposedHelpers.getObjectField(objectField, "appInfo");
            CompatibilityInfo compatibilityInfo = (CompatibilityInfo) XposedHelpers.getObjectField(objectField, "compatInfo");
            ClassLoader classLoader = stubLoadedApk.getClassLoader();
            try {
                InputStream resourceAsStream = classLoader.getResourceAsStream(Constants.CONFIG_ASSET_PATH);
                try {
                    config = (PatchConfig) new Gson().fromJson((Reader) new BufferedReader(new InputStreamReader(resourceAsStream, StandardCharsets.UTF_8)), PatchConfig.class);
                    if (resourceAsStream != null) {
                        resourceAsStream.close();
                    }
                    Log.i(TAG, "Use manager: " + config.useManager);
                    Log.i(TAG, "Signature bypass level: " + config.sigBypassLevel);
                    Path path = Paths.get(applicationInfo.dataDir, "cache/lspatch/origin/");
                    ZipFile zipFile = new ZipFile(applicationInfo.sourceDir);
                    try {
                        Path resolve = path.resolve(zipFile.getEntry(Constants.ORIGINAL_APK_ASSET_PATH).getCrc() + ".apk");
                        zipFile.close();
                        applicationInfo.sourceDir = resolve.toString();
                        applicationInfo.publicSourceDir = resolve.toString();
                        applicationInfo.appComponentFactory = config.appComponentFactory;
                        if (!Files.exists(resolve, new LinkOption[0])) {
                            Log.i(TAG, "Extract original apk");
                            FileUtils.deleteFolderIfExists(path);
                            Files.createDirectories(path, new FileAttribute[0]);
                            InputStream resourceAsStream2 = classLoader.getResourceAsStream(Constants.ORIGINAL_APK_ASSET_PATH);
                            try {
                                Files.copy(resourceAsStream2, resolve, new CopyOption[0]);
                                if (resourceAsStream2 != null) {
                                    resourceAsStream2.close();
                                }
                            } catch (Throwable th) {
                                th.addSuppressed(th);
                            }
                        }
                        ((Map) XposedHelpers.getObjectField(activityThread, "mPackages")).remove(applicationInfo.packageName);
                        LoadedApk packageInfoNoCheck = activityThread.getPackageInfoNoCheck(applicationInfo, compatibilityInfo);
                        appLoadedApk = packageInfoNoCheck;
                        XposedHelpers.setObjectField(objectField, "info", packageInfoNoCheck);
                        LSPApplication$$ExternalSyntheticLambda0 lSPApplication$$ExternalSyntheticLambda0 = new LSPApplication$$ExternalSyntheticLambda0(XposedHelpers.findClass("android.app.ActivityThread$ActivityClientRecord", ActivityThread.class.getClassLoader()));
                        ((Map) XposedHelpers.getObjectField(activityThread, "mActivities")).forEach(lSPApplication$$ExternalSyntheticLambda0);
                        try {
                            if (Build.VERSION.SDK_INT >= 31) {
                                ((Map) XposedHelpers.getObjectField(activityThread, "mLaunchingActivities")).forEach(lSPApplication$$ExternalSyntheticLambda0);
                            }
                        } catch (Throwable unused) {
                        }
                        Log.i(TAG, "hooked app initialized: " + appLoadedApk);
                        Context context = (Context) XposedHelpers.callStaticMethod(Class.forName("android.app.ContextImpl"), "createAppContext", activityThread, stubLoadedApk);
                        if (config.appComponentFactory != null) {
                            try {
                                context.getClassLoader().loadClass(config.appComponentFactory);
                            } catch (ClassNotFoundException unused2) {
                                Log.w(TAG, "Original AppComponentFactory not found: " + config.appComponentFactory);
                                applicationInfo.appComponentFactory = null;
                            }
                        }
                        return context;
                    } catch (Throwable th2) {
                        th.addSuppressed(th2);
                    }
                    throw th;
                    throw th;
                    throw th;
                } catch (Throwable th3) {
                    th.addSuppressed(th3);
                }
            } catch (IOException unused3) {
                Log.e(TAG, "Failed to load config file");
                return null;
            }
        } catch (Throwable th4) {
            Log.e(TAG, "createLoadedApk", th4);
            return null;
        }
    }

    static /* synthetic */ void lambda$createLoadedApkWithContext$0(Class cls, Object obj, Object obj2) {
        if (cls.isInstance(obj2) && XposedHelpers.getObjectField(obj2, "packageInfo") == stubLoadedApk) {
            Log.d(TAG, "fix loadedapk from ActivityClientRecord");
            XposedHelpers.setObjectField(obj2, "packageInfo", appLoadedApk);
        }
    }

    public static void disableProfile(Context context) {
        String str;
        ArrayList arrayList = new ArrayList();
        ApplicationInfo applicationInfo = context.getApplicationInfo();
        String packageName = context.getPackageName();
        if (applicationInfo != null) {
            if ((applicationInfo.flags & 4) != 0) {
                arrayList.add(applicationInfo.sourceDir);
            }
            if (applicationInfo.splitSourceDirs != null) {
                Collections.addAll(arrayList, applicationInfo.splitSourceDirs);
            }
            if (!arrayList.isEmpty()) {
                File Environment_getDataProfilesDePackageDirectory = HiddenApiBridge.Environment_getDataProfilesDePackageDirectory(applicationInfo.uid / PER_USER_RANGE, packageName);
                FileAttribute<Set<PosixFilePermission>> asFileAttribute = PosixFilePermissions.asFileAttribute(PosixFilePermissions.fromString("r--------"));
                for (int size = arrayList.size() - 1; size >= 0; size--) {
                    if (size == 0) {
                        str = null;
                    } else {
                        str = applicationInfo.splitNames[size - 1];
                    }
                    File absoluteFile = new File(Environment_getDataProfilesDePackageDirectory, str == null ? "primary.prof" : str + ".split.prof").getAbsoluteFile();
                    Log.d(TAG, "Processing " + absoluteFile.getAbsolutePath());
                    try {
                        if (!absoluteFile.canWrite() && Files.size(absoluteFile.toPath()) == 0) {
                            Log.d(TAG, "Skip profile " + absoluteFile.getAbsolutePath());
                        } else if (!absoluteFile.exists() || absoluteFile.delete()) {
                            Files.createFile(absoluteFile.toPath(), asFileAttribute);
                        } else {
                            try {
                                FileOutputStream fileOutputStream = new FileOutputStream(absoluteFile);
                                try {
                                    Log.d(TAG, "Failed to delete, try to clear content " + absoluteFile.getAbsolutePath());
                                    fileOutputStream.close();
                                } catch (Throwable th) {
                                    th.addSuppressed(th);
                                }
                            } catch (Throwable th2) {
                                Log.e(TAG, "Failed to delete and clear profile file " + absoluteFile.getAbsolutePath(), th2);
                            }
                            Os.chmod(absoluteFile.getAbsolutePath(), ResConst.RES_XML_START_NAMESPACE_TYPE);
                        }
                    } catch (Throwable th3) {
                        Log.e(TAG, "Failed to disable profile file " + absoluteFile.getAbsolutePath(), th3);
                    }
                }
                return;
            }
            return;
        }
        return;
        throw th;
    }

    private static void switchAllClassLoader() {
        Field[] declaredFields = LoadedApk.class.getDeclaredFields();
        for (Field field : declaredFields) {
            if (field.getType() == ClassLoader.class) {
                XposedHelpers.setObjectField(stubLoadedApk, field.getName(), XposedHelpers.getObjectField(appLoadedApk, field.getName()));
            }
        }
    }
}
