package org.lsposed.lspatch.service;

import android.content.ComponentName;
import android.content.Context;
import android.content.Intent;
import android.content.ServiceConnection;
import android.os.Build;
import android.os.Bundle;
import android.os.Environment;
import android.os.Handler;
import android.os.HandlerThread;
import android.os.IBinder;
import android.os.ParcelFileDescriptor;
import android.os.RemoteException;
import android.os.UserHandle;
import android.util.Log;
import android.widget.Toast;
import java.io.File;
import java.lang.reflect.InvocationTargetException;
import java.lang.reflect.Method;
import java.util.ArrayList;
import java.util.List;
import java.util.concurrent.CountDownLatch;
import java.util.concurrent.Executors;
import java.util.concurrent.TimeUnit;
import java.util.concurrent.TimeoutException;
import org.lsposed.lspatch.share.Constants;
import org.lsposed.lspd.models.Module;
import org.lsposed.lspd.service.ILSPApplicationService;

public class RemoteApplicationService implements ILSPApplicationService {
    private static final String MODULE_SERVICE = "org.lsposed.lspatch.manager.ModuleService";
    private static final String TAG = "LSPatch";
    private ILSPApplicationService service;

    @Override // org.lsposed.lspd.service.ILSPApplicationService
    public ParcelFileDescriptor requestInjectedManagerBinder(List<IBinder> list) {
        return null;
    }

    public RemoteApplicationService(Context context) throws RemoteException {
        Throwable e;
        try {
            Intent putExtra = new Intent().setComponent(new ComponentName(Constants.MANAGER_PACKAGE_NAME, MODULE_SERVICE)).putExtra("packageName", context.getPackageName());
            final CountDownLatch countDownLatch = new CountDownLatch(1);
            try {
                AnonymousClass1 r5 = new ServiceConnection() {
                    /* class org.lsposed.lspatch.service.RemoteApplicationService.AnonymousClass1 */

                    public void onServiceConnected(ComponentName componentName, IBinder iBinder) {
                        Log.i(RemoteApplicationService.TAG, "Manager binder received");
                        countDownLatch.countDown();
                        RemoteApplicationService.this.service = ILSPApplicationService.Stub.asInterface(iBinder);
                    }

                    public void onServiceDisconnected(ComponentName componentName) {
                        Log.e(RemoteApplicationService.TAG, "Manager service died");
                        RemoteApplicationService.this.service = null;
                    }
                };
                Log.i(TAG, "Request manager binder");
                if (Build.VERSION.SDK_INT >= 29) {
                    context.bindService(putExtra, 1, Executors.newSingleThreadExecutor(), r5);
                } else {
                    HandlerThread handlerThread = new HandlerThread("RemoteApplicationService");
                    handlerThread.start();
                    Handler handler = new Handler(handlerThread.getLooper());
                    Class<?> cls = context.getClass();
                    Method method = cls.getMethod("getUser", new Class[0]);
                    cls.getDeclaredMethod("bindServiceAsUser", Intent.class, ServiceConnection.class, Integer.TYPE, Handler.class, UserHandle.class).invoke(context, putExtra, r5, 1, handler, (UserHandle) method.invoke(context, new Object[0]));
                }
                if (!countDownLatch.await(1, TimeUnit.SECONDS)) {
                    throw new TimeoutException("Bind service timeout");
                }
            } catch (IllegalAccessException | InterruptedException | NoSuchMethodException | InvocationTargetException | TimeoutException e2) {
                e = e2;
                Toast.makeText(context, "Manager died", 0).show();
                RemoteException remoteException = new RemoteException("Failed to get manager binder");
                remoteException.initCause(e);
                throw remoteException;
            }
        } catch (IllegalAccessException | InterruptedException | NoSuchMethodException | InvocationTargetException | TimeoutException e3) {
            e = e3;
            Toast.makeText(context, "Manager died", 0).show();
            RemoteException remoteException2 = new RemoteException("Failed to get manager binder");
            remoteException2.initCause(e);
            throw remoteException2;
        }
    }

    @Override // org.lsposed.lspd.service.ILSPApplicationService
    public IBinder requestModuleBinder(String str) {
        ILSPApplicationService iLSPApplicationService = this.service;
        if (iLSPApplicationService == null) {
            return null;
        }
        return iLSPApplicationService.asBinder();
    }

    @Override // org.lsposed.lspd.service.ILSPApplicationService
    public List<Module> getModulesList() throws RemoteException {
        ILSPApplicationService iLSPApplicationService = this.service;
        return iLSPApplicationService == null ? new ArrayList() : iLSPApplicationService.getModulesList();
    }

    @Override // org.lsposed.lspd.service.ILSPApplicationService
    public String getPrefsPath(String str) {
        return new File(Environment.getDataDirectory(), "data/" + str + "/shared_prefs/").getAbsolutePath();
    }

    @Override // org.lsposed.lspd.service.ILSPApplicationService
    public Bundle requestRemotePreference(String str, int i, IBinder iBinder) throws RemoteException {
        ILSPApplicationService iLSPApplicationService = this.service;
        if (iLSPApplicationService == null) {
            return null;
        }
        return iLSPApplicationService.requestRemotePreference(str, i, iBinder);
    }

    public IBinder asBinder() {
        ILSPApplicationService iLSPApplicationService = this.service;
        if (iLSPApplicationService == null) {
            return null;
        }
        return iLSPApplicationService.asBinder();
    }
}
