package org.lsposed.lspd.core;

import android.app.ActivityThread;
import android.app.LoadedApk;
import android.content.pm.ApplicationInfo;
import android.content.res.CompatibilityInfo;
import com.android.internal.os.ZygoteInit;
import dalvik.system.DexFile;
import de.robv.android.xposed.XposedBridge;
import de.robv.android.xposed.XposedHelpers;
import de.robv.android.xposed.XposedInit;
import org.lsposed.lspd.deopt.PrebuiltMethodsDeopter;
import org.lsposed.lspd.hooker.CrashDumpHooker;
import org.lsposed.lspd.hooker.HandleSystemServerProcessHooker;
import org.lsposed.lspd.hooker.LoadedApkCtorHooker;
import org.lsposed.lspd.hooker.OpenDexFileHooker;
import org.lsposed.lspd.service.ILSPApplicationService;
import org.lsposed.lspd.util.Utils;

public class Startup {
    private static void startBootstrapHook(boolean z) {
        Utils.logD("startBootstrapHook starts: isSystem = " + z);
        XposedHelpers.findAndHookMethod(Thread.class, "dispatchUncaughtException", Throwable.class, new CrashDumpHooker());
        if (z) {
            XposedBridge.hookAllMethods(ZygoteInit.class, "handleSystemServerProcess", new HandleSystemServerProcessHooker());
        } else {
            OpenDexFileHooker openDexFileHooker = new OpenDexFileHooker();
            XposedBridge.hookAllMethods(DexFile.class, "openDexFile", openDexFileHooker);
            XposedBridge.hookAllMethods(DexFile.class, "openInMemoryDexFile", openDexFileHooker);
            XposedBridge.hookAllMethods(DexFile.class, "openInMemoryDexFiles", openDexFileHooker);
        }
        XposedHelpers.findAndHookConstructor(LoadedApk.class, ActivityThread.class, ApplicationInfo.class, CompatibilityInfo.class, ClassLoader.class, Boolean.TYPE, Boolean.TYPE, Boolean.TYPE, new LoadedApkCtorHooker());
    }

    public static void bootstrapXposed() {
        try {
            startBootstrapHook(XposedInit.startsSystemServer);
            XposedInit.loadModules();
        } catch (Throwable th) {
            Utils.logE("error during Xposed initialization", th);
        }
    }

    public static void initXposed(boolean z, String str, ILSPApplicationService iLSPApplicationService) {
        ApplicationServiceClient.Init(iLSPApplicationService, str);
        XposedBridge.initXResources();
        XposedInit.startsSystemServer = z;
        PrebuiltMethodsDeopter.deoptBootMethods();
    }
}
