package org.lsposed.lspd.hooker;

import android.app.ActivityThread;
import android.app.AndroidAppHelper;
import android.app.LoadedApk;
import de.robv.android.xposed.XC_MethodHook;
import de.robv.android.xposed.XC_MethodReplacement;
import de.robv.android.xposed.XposedBridge;
import de.robv.android.xposed.XposedHelpers;
import de.robv.android.xposed.callbacks.XC_LoadPackage;
import java.io.File;
import java.io.IOException;
import java.util.Map;
import org.lsposed.lspd.core.ApplicationServiceClient;
import org.lsposed.lspd.util.Hookers;
import org.lsposed.lspd.util.MetaDataReader;
import org.lsposed.lspd.util.Utils;

public class LoadedApkGetCLHooker extends XC_MethodHook {
    private final LoadedApk loadedApk;
    private final XC_MethodHook.Unhook unhook = XposedHelpers.findAndHookMethod(LoadedApk.class, "getClassLoader", this);

    public LoadedApkGetCLHooker(LoadedApk loadedApk2) {
        this.loadedApk = loadedApk2;
    }

    /* access modifiers changed from: protected */
    @Override // de.robv.android.xposed.XC_MethodHook
    public void afterHookedMethod(XC_MethodHook.MethodHookParam methodHookParam) {
        LoadedApk loadedApk2 = (LoadedApk) methodHookParam.thisObject;
        if (loadedApk2 == this.loadedApk) {
            try {
                Hookers.logD("LoadedApk#getClassLoader starts");
                String currentPackageName = ActivityThread.currentPackageName();
                String currentProcessName = ActivityThread.currentProcessName();
                boolean z = (currentPackageName == null || currentProcessName == null || !currentPackageName.equals(loadedApk2.getPackageName())) ? false : true;
                if (!z) {
                    currentPackageName = loadedApk2.getPackageName();
                    currentProcessName = AndroidAppHelper.currentProcessName();
                } else if (currentPackageName.equals("android")) {
                    currentPackageName = "system";
                }
                Object objectField = XposedHelpers.getObjectField(loadedApk2, "mAppDir");
                ClassLoader classLoader = (ClassLoader) methodHookParam.getResult();
                Hookers.logD("LoadedApk#getClassLoader ends: " + objectField + " -> " + classLoader);
                if (classLoader == null) {
                    this.unhook.unhook();
                    return;
                }
                XC_LoadPackage.LoadPackageParam loadPackageParam = new XC_LoadPackage.LoadPackageParam(XposedBridge.sLoadedPackageCallbacks);
                loadPackageParam.packageName = currentPackageName;
                loadPackageParam.processName = currentProcessName;
                loadPackageParam.classLoader = classLoader;
                loadPackageParam.appInfo = loadedApk2.getApplicationInfo();
                loadPackageParam.isFirstApplication = z;
                if (ApplicationServiceClient.serviceClient.requestModuleBinder(loadPackageParam.packageName) != null) {
                    hookNewXSP(loadPackageParam);
                }
                Hookers.logD("Call handleLoadedPackage: packageName=" + loadPackageParam.packageName + " processName=" + loadPackageParam.processName + " isFirstApplication=" + z + " classLoader=" + loadPackageParam.classLoader + " appInfo=" + loadPackageParam.appInfo);
                XC_LoadPackage.callAll(loadPackageParam);
                this.unhook.unhook();
            } catch (Throwable th) {
                this.unhook.unhook();
                throw th;
            }
        }
    }

    private void hookNewXSP(final XC_LoadPackage.LoadPackageParam loadPackageParam) {
        boolean z;
        int i = -1;
        try {
            Map<String, Object> metaData = MetaDataReader.getMetaData(new File(loadPackageParam.appInfo.sourceDir));
            Object obj = metaData.get("xposedminversion");
            if (obj instanceof Integer) {
                i = ((Integer) obj).intValue();
            } else if (obj instanceof String) {
                i = MetaDataReader.extractIntPart((String) obj);
            }
            z = metaData.containsKey("xposedsharedprefs");
        } catch (IOException | NumberFormatException e) {
            Hookers.logE("ApkParser fails", e);
            z = false;
        }
        if (i > 92 || z) {
            Utils.logW("New modules detected, hook preferences");
            XposedHelpers.findAndHookMethod("android.app.ContextImpl", loadPackageParam.classLoader, "checkMode", Integer.TYPE, new XC_MethodHook() {
                /* class org.lsposed.lspd.hooker.LoadedApkGetCLHooker.AnonymousClass1 */

                /* access modifiers changed from: protected */
                @Override // de.robv.android.xposed.XC_MethodHook
                public void afterHookedMethod(XC_MethodHook.MethodHookParam methodHookParam) {
                    if ((((Integer) methodHookParam.args[0]).intValue() & 1) != 0) {
                        methodHookParam.setThrowable(null);
                    }
                }
            });
            XposedHelpers.findAndHookMethod("android.app.ContextImpl", loadPackageParam.classLoader, "getPreferencesDir", new XC_MethodReplacement() {
                /* class org.lsposed.lspd.hooker.LoadedApkGetCLHooker.AnonymousClass2 */

                /* access modifiers changed from: protected */
                @Override // de.robv.android.xposed.XC_MethodReplacement
                public Object replaceHookedMethod(XC_MethodHook.MethodHookParam methodHookParam) {
                    return new File(ApplicationServiceClient.serviceClient.getPrefsPath(loadPackageParam.packageName));
                }
            });
        }
    }
}
