package org.lsposed.lspd.util;

import java.io.ByteArrayOutputStream;
import java.io.File;
import java.io.IOException;
import java.io.InputStream;
import java.util.HashMap;
import java.util.Map;
import java.util.jar.JarFile;
import pxb.android.axml.AxmlReader;
import pxb.android.axml.AxmlVisitor;
import pxb.android.axml.NodeVisitor;

public class MetaDataReader {
    private final HashMap<String, Object> metaData = new HashMap<>();

    public static Map<String, Object> getMetaData(File file) throws IOException {
        return new MetaDataReader(file).metaData;
    }

    private MetaDataReader(File file) throws IOException {
        JarFile jarFile = new JarFile(file);
        try {
            byte[] bytesFromInputStream = getBytesFromInputStream(jarFile.getInputStream(jarFile.getEntry("AndroidManifest.xml")));
            AxmlReader axmlReader = bytesFromInputStream != null ? new AxmlReader(bytesFromInputStream) : null;
            if (axmlReader != null) {
                axmlReader.accept(new AxmlVisitor() {
                    /* class org.lsposed.lspd.util.MetaDataReader.AnonymousClass1 */

                    @Override // pxb.android.axml.NodeVisitor
                    public NodeVisitor child(String str, String str2) {
                        return new ManifestTagVisitor(super.child(str, str2));
                    }
                });
            }
            jarFile.close();
            return;
        } catch (Throwable th) {
            th.addSuppressed(th);
        }
        throw th;
    }

    public static byte[] getBytesFromInputStream(InputStream inputStream) throws IOException {
        try {
            ByteArrayOutputStream byteArrayOutputStream = new ByteArrayOutputStream();
            try {
                byte[] bArr = new byte[1024];
                while (true) {
                    int read = inputStream.read(bArr);
                    if (read != -1) {
                        byteArrayOutputStream.write(bArr, 0, read);
                    } else {
                        byte[] byteArray = byteArrayOutputStream.toByteArray();
                        byteArrayOutputStream.close();
                        return byteArray;
                    }
                }
            } catch (Throwable th) {
                th.addSuppressed(th);
            }
            throw th;
        } catch (Exception e) {
            e.printStackTrace();
            return null;
        }
    }

    private class ManifestTagVisitor extends NodeVisitor {
        public ManifestTagVisitor(NodeVisitor nodeVisitor) {
            super(nodeVisitor);
        }

        @Override // pxb.android.axml.NodeVisitor
        public NodeVisitor child(String str, String str2) {
            NodeVisitor child = super.child(str, str2);
            return "application".equals(str2) ? new ApplicationTagVisitor(child) : child;
        }

        private class ApplicationTagVisitor extends NodeVisitor {
            public ApplicationTagVisitor(NodeVisitor nodeVisitor) {
                super(nodeVisitor);
            }

            @Override // pxb.android.axml.NodeVisitor
            public NodeVisitor child(String str, String str2) {
                NodeVisitor child = super.child(str, str2);
                return "meta-data".equals(str2) ? new MetaDataVisitor(child) : child;
            }
        }
    }

    private class MetaDataVisitor extends NodeVisitor {
        public String name = null;
        public Object value = null;

        public MetaDataVisitor(NodeVisitor nodeVisitor) {
            super(nodeVisitor);
        }

        @Override // pxb.android.axml.NodeVisitor
        public void attr(String str, String str2, int i, int i2, Object obj) {
            if (i2 == 3 && "name".equals(str2)) {
                this.name = (String) obj;
            }
            if ("value".equals(str2)) {
                this.value = obj;
            }
            super.attr(str, str2, i, i2, obj);
        }

        @Override // pxb.android.axml.NodeVisitor
        public void end() {
            if (!(this.name == null || this.value == null)) {
                MetaDataReader.this.metaData.put(this.name, this.value);
            }
            super.end();
        }
    }

    public static int extractIntPart(String str) {
        int length = str.length();
        int i = 0;
        for (int i2 = 0; i2 < length; i2++) {
            char charAt = str.charAt(i2);
            if ('0' > charAt || charAt > '9') {
                break;
            }
            i = (i * 10) + (charAt - '0');
        }
        return i;
    }
}
