package pxb.android.arsc;

import java.io.IOException;
import java.nio.ByteBuffer;
import java.nio.ByteOrder;
import java.util.AbstractMap;
import java.util.ArrayList;
import java.util.List;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import pxb.android.ResConst;
import pxb.android.StringItems;

public class ArscParser implements ResConst {
    static final int ENGRY_FLAG_PUBLIC = 2;
    static final short ENTRY_FLAG_COMPLEX = 1;
    public static final int TYPE_STRING = 3;
    private static final Logger logger = LoggerFactory.getLogger(ArscParser.class);
    private int fileSize = -1;
    private ByteBuffer in;
    private String[] keyNamesX;
    private Pkg pkg;
    private List<Pkg> pkgs = new ArrayList();
    private String[] strings;
    private String[] typeNamesX;

    /* access modifiers changed from: package-private */
    public class Chunk {
        public final int headSize;
        public final int location;
        public final int size;
        public final int type;

        public Chunk() {
            int position = ArscParser.this.in.position();
            this.location = position;
            int i = ArscParser.this.in.getShort() & 65535;
            this.type = i;
            int i2 = 65535 & ArscParser.this.in.getShort();
            this.headSize = i2;
            int i3 = ArscParser.this.in.getInt();
            this.size = i3;
            ArscParser.D("[%08x]type: %04x, headsize: %04x, size:%08x", new Object[]{Integer.valueOf(position), Integer.valueOf(i), Integer.valueOf(i2), Integer.valueOf(i3)});
        }
    }

    /* access modifiers changed from: private */
    public static void D(String str, Object... objArr) {
        Logger logger2 = logger;
        if (logger2.isTraceEnabled()) {
            logger2.trace(String.format(str, objArr));
        }
    }

    public ArscParser(byte[] bArr) {
        this.in = ByteBuffer.wrap(bArr).order(ByteOrder.LITTLE_ENDIAN);
    }

    public List<Pkg> parse() throws IOException {
        if (this.fileSize < 0) {
            Chunk chunk = new Chunk();
            if (chunk.type == 2) {
                this.fileSize = chunk.size;
                this.in.getInt();
            } else {
                throw new RuntimeException();
            }
        }
        while (this.in.hasRemaining()) {
            Chunk chunk2 = new Chunk();
            int i = chunk2.type;
            if (i == 1) {
                this.strings = StringItems.read(this.in);
                if (logger.isTraceEnabled()) {
                    for (int i2 = 0; i2 < this.strings.length; i2++) {
                        D("STR [%08x] %s", Integer.valueOf(i2), this.strings[i2]);
                    }
                }
            } else if (i == 512) {
                readPackage(this.in);
            }
            this.in.position(chunk2.location + chunk2.size);
        }
        return this.pkgs;
    }

    private void readEntry(Config config, ResSpec resSpec) {
        D("[%08x]read ResTable_entry", Integer.valueOf(this.in.position()));
        D("ResTable_entry %d", Integer.valueOf(this.in.getShort()));
        short s = this.in.getShort();
        resSpec.updateName(this.keyNamesX[this.in.getInt()]);
        ResEntry resEntry = new ResEntry(s, resSpec);
        if ((1 & s) != 0) {
            int i = this.in.getInt();
            int i2 = this.in.getInt();
            BagValue bagValue = new BagValue(i);
            for (int i3 = 0; i3 < i2; i3++) {
                bagValue.map.add(new AbstractMap.SimpleEntry(Integer.valueOf(this.in.getInt()), readValue()));
            }
            resEntry.value = bagValue;
        } else {
            resEntry.value = readValue();
        }
        config.resources.put(Integer.valueOf(resSpec.id), resEntry);
    }

    private void readPackage(ByteBuffer byteBuffer) throws IOException {
        short s;
        int i = byteBuffer.getInt() % 255;
        int position = byteBuffer.position() + ResConst.RES_XML_START_NAMESPACE_TYPE;
        StringBuilder sb = new StringBuilder(32);
        for (int i2 = 0; i2 < 128 && (s = byteBuffer.getShort()) != 0; i2++) {
            sb.append((char) s);
        }
        String sb2 = sb.toString();
        byteBuffer.position(position);
        Pkg pkg2 = new Pkg(i, sb2);
        this.pkg = pkg2;
        this.pkgs.add(pkg2);
        byteBuffer.getInt();
        byteBuffer.getInt();
        byteBuffer.getInt();
        byteBuffer.getInt();
        Chunk chunk = new Chunk();
        if (chunk.type == 1) {
            this.typeNamesX = StringItems.read(byteBuffer);
            byteBuffer.position(chunk.location + chunk.size);
            Chunk chunk2 = new Chunk();
            if (chunk2.type == 1) {
                this.keyNamesX = StringItems.read(byteBuffer);
                if (logger.isTraceEnabled()) {
                    for (int i3 = 0; i3 < this.keyNamesX.length; i3++) {
                        D("STR [%08x] %s", Integer.valueOf(i3), this.keyNamesX[i3]);
                    }
                }
                byteBuffer.position(chunk2.location + chunk2.size);
                while (byteBuffer.hasRemaining()) {
                    Chunk chunk3 = new Chunk();
                    int i4 = chunk3.type;
                    if (i4 == 513) {
                        D("[%08x]read config", Integer.valueOf(byteBuffer.position() - 8));
                        int i5 = byteBuffer.get() & 255;
                        byteBuffer.get();
                        byteBuffer.getShort();
                        int i6 = byteBuffer.getInt();
                        Type type = this.pkg.getType(i5, this.typeNamesX[i5 - 1], i6);
                        int i7 = byteBuffer.getInt();
                        D("[%08x]read config id", Integer.valueOf(byteBuffer.position()));
                        int position2 = byteBuffer.position();
                        byte[] bArr = new byte[byteBuffer.getInt()];
                        byteBuffer.position(position2);
                        byteBuffer.get(bArr);
                        Config config = new Config(bArr, i6);
                        byteBuffer.position(chunk3.location + chunk3.headSize);
                        D("[%08x]read config entry offset", Integer.valueOf(byteBuffer.position()));
                        int[] iArr = new int[i6];
                        for (int i8 = 0; i8 < i6; i8++) {
                            iArr[i8] = byteBuffer.getInt();
                        }
                        D("[%08x]read config entrys", Integer.valueOf(byteBuffer.position()));
                        for (int i9 = 0; i9 < i6; i9++) {
                            if (iArr[i9] != -1) {
                                byteBuffer.position(chunk3.location + i7 + iArr[i9]);
                                readEntry(config, type.getSpec(i9));
                            }
                        }
                        type.addConfig(config);
                    } else if (i4 == 514) {
                        D("[%08x]read spec", Integer.valueOf(byteBuffer.position() - 8));
                        int i10 = byteBuffer.get() & 255;
                        byteBuffer.get();
                        byteBuffer.getShort();
                        int i11 = byteBuffer.getInt();
                        Type type2 = this.pkg.getType(i10, this.typeNamesX[i10 - 1], i11);
                        for (int i12 = 0; i12 < i11; i12++) {
                            type2.getSpec(i12).flags = byteBuffer.getInt();
                        }
                    } else {
                        return;
                    }
                    byteBuffer.position(chunk3.location + chunk3.size);
                }
                return;
            }
            throw new RuntimeException();
        }
        throw new RuntimeException();
    }

    private Object readValue() {
        this.in.getShort();
        this.in.get();
        int i = this.in.get() & 255;
        int i2 = this.in.getInt();
        return new Value(i, i2, i == 3 ? this.strings[i2] : null);
    }
}
