package pxb.android.arsc;

import java.io.File;
import java.io.IOException;
import java.nio.ByteBuffer;
import java.nio.ByteOrder;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.Iterator;
import java.util.List;
import java.util.Map;
import java.util.TreeMap;
import org.apache.commons.lang3.CharEncoding;
import pxb.android.ResConst;
import pxb.android.StringItem;
import pxb.android.StringItems;
import pxb.android.axml.Util;

public class ArscWriter implements ResConst {
    private List<PkgCtx> ctxs = new ArrayList(5);
    private List<Pkg> pkgs;
    private Map<String, StringItem> strTable = new TreeMap();
    private StringItems strTable0 = new StringItems();

    private static void D(String str, Object... objArr) {
    }

    /* access modifiers changed from: private */
    public static class PkgCtx {
        Map<String, StringItem> keyNames;
        StringItems keyNames0;
        public int keyStringOff;
        int offset;
        Pkg pkg;
        int pkgSize;
        List<StringItem> typeNames;
        StringItems typeNames0;
        int typeStringOff;

        private PkgCtx() {
            this.keyNames = new HashMap();
            this.keyNames0 = new StringItems();
            this.typeNames = new ArrayList();
            this.typeNames0 = new StringItems();
        }

        public void addKeyName(String str) {
            if (!this.keyNames.containsKey(str)) {
                StringItem stringItem = new StringItem(str);
                this.keyNames.put(str, stringItem);
                this.keyNames0.add(stringItem);
            }
        }

        public void addTypeName(int i, String str) {
            while (this.typeNames.size() <= i) {
                this.typeNames.add(null);
            }
            if (this.typeNames.get(i) == null) {
                this.typeNames.set(i, new StringItem(str));
                return;
            }
            throw new RuntimeException();
        }
    }

    public ArscWriter(List<Pkg> list) {
        this.pkgs = list;
    }

    public static void main(String... strArr) throws IOException {
        if (strArr.length < 2) {
            System.err.println("asrc-write-test in.arsc out.arsc");
        } else {
            Util.writeFile(new ArscWriter(new ArscParser(Util.readFile(new File(strArr[0]))).parse()).toByteArray(), new File(strArr[1]));
        }
    }

    private void addString(String str) {
        if (!this.strTable.containsKey(str)) {
            StringItem stringItem = new StringItem(str);
            this.strTable.put(str, stringItem);
            this.strTable0.add(stringItem);
        }
    }

    private int count() {
        int size = this.strTable0.getSize();
        int i = size % 4;
        if (i != 0) {
            size += 4 - i;
        }
        int i2 = size + 8 + 12;
        for (PkgCtx pkgCtx : this.ctxs) {
            pkgCtx.offset = i2;
            pkgCtx.typeStringOff = 284;
            int size2 = pkgCtx.typeNames0.getSize();
            int i3 = size2 % 4;
            if (i3 != 0) {
                size2 += 4 - i3;
            }
            int i4 = 284 + size2 + 8;
            pkgCtx.keyStringOff = i4;
            int size3 = pkgCtx.keyNames0.getSize();
            int i5 = size3 % 4;
            if (i5 != 0) {
                size3 += 4 - i5;
            }
            int i6 = i4 + size3 + 8;
            for (Type type : pkgCtx.pkg.types.values()) {
                type.wPosition = i2 + i6;
                i6 += (type.specs.length * 4) + 16;
                Iterator<Config> it = type.configs.iterator();
                while (true) {
                    if (it.hasNext()) {
                        Config next = it.next();
                        next.wPosition = i6 + i2;
                        int i7 = i6 + 20;
                        int length = next.id.length;
                        int i8 = length % 4;
                        if (i8 != 0) {
                            length += 4 - i8;
                        }
                        if ((i7 + length) - i6 <= 56) {
                            int i9 = i6 + 56 + (next.entryCount * 4);
                            next.wEntryStart = i9 - i6;
                            int i10 = i9;
                            for (ResEntry resEntry : next.resources.values()) {
                                resEntry.wOffset = i10 - i9;
                                int i11 = i10 + 8;
                                i10 = resEntry.value instanceof BagValue ? i11 + (((BagValue) resEntry.value).map.size() * 12) + 8 : i11 + 8;
                            }
                            next.wChunkSize = i10 - i6;
                            i6 = i10;
                        } else {
                            throw new RuntimeException("config id  too big");
                        }
                    }
                }
            }
            pkgCtx.pkgSize = i6;
            i2 += i6;
        }
        return i2;
    }

    private List<PkgCtx> prepare() throws IOException {
        for (Pkg pkg : this.pkgs) {
            PkgCtx pkgCtx = new PkgCtx();
            pkgCtx.pkg = pkg;
            this.ctxs.add(pkgCtx);
            for (Type type : pkg.types.values()) {
                pkgCtx.addTypeName(type.id - 1, type.name);
                for (ResSpec resSpec : type.specs) {
                    pkgCtx.addKeyName(resSpec.name);
                }
                for (Config config : type.configs) {
                    for (ResEntry resEntry : config.resources.values()) {
                        Object obj = resEntry.value;
                        if (obj instanceof BagValue) {
                            travelBagValue((BagValue) obj);
                        } else {
                            travelValue((Value) obj);
                        }
                    }
                }
            }
            pkgCtx.keyNames0.prepare();
            pkgCtx.typeNames0.addAll(pkgCtx.typeNames);
            pkgCtx.typeNames0.prepare();
        }
        this.strTable0.prepare();
        return this.ctxs;
    }

    public byte[] toByteArray() throws IOException {
        prepare();
        int count = count();
        ByteBuffer order = ByteBuffer.allocate(count).order(ByteOrder.LITTLE_ENDIAN);
        write(order, count);
        return order.array();
    }

    private void travelBagValue(BagValue bagValue) {
        for (Map.Entry<Integer, Value> entry : bagValue.map) {
            travelValue(entry.getValue());
        }
    }

    private void travelValue(Value value) {
        if (value.raw != null) {
            addString(value.raw);
        }
    }

    private void write(ByteBuffer byteBuffer, int i) throws IOException {
        byteBuffer.putInt(786434);
        byteBuffer.putInt(i);
        byteBuffer.putInt(this.ctxs.size());
        int size = this.strTable0.getSize();
        int i2 = size % 4;
        int i3 = i2 != 0 ? 4 - i2 : 0;
        int i4 = 1835009;
        byteBuffer.putInt(1835009);
        byteBuffer.putInt(size + i3 + 8);
        this.strTable0.write(byteBuffer);
        byteBuffer.put(new byte[i3]);
        for (PkgCtx pkgCtx : this.ctxs) {
            if (byteBuffer.position() == pkgCtx.offset) {
                int position = byteBuffer.position();
                byteBuffer.putInt(18612736);
                byteBuffer.putInt(pkgCtx.pkgSize);
                byteBuffer.putInt(pkgCtx.pkg.id);
                int position2 = byteBuffer.position();
                byteBuffer.put(pkgCtx.pkg.name.getBytes(CharEncoding.UTF_16LE));
                byteBuffer.position(position2 + ResConst.RES_XML_START_NAMESPACE_TYPE);
                byteBuffer.putInt(pkgCtx.typeStringOff);
                byteBuffer.putInt(pkgCtx.typeNames0.size());
                byteBuffer.putInt(pkgCtx.keyStringOff);
                byteBuffer.putInt(pkgCtx.keyNames0.size());
                if (byteBuffer.position() - position == pkgCtx.typeStringOff) {
                    int size2 = pkgCtx.typeNames0.getSize();
                    int i5 = size2 % 4;
                    int i6 = i5 != 0 ? 4 - i5 : 0;
                    byteBuffer.putInt(i4);
                    byteBuffer.putInt(size2 + i6 + 8);
                    pkgCtx.typeNames0.write(byteBuffer);
                    byteBuffer.put(new byte[i6]);
                    if (byteBuffer.position() - position == pkgCtx.keyStringOff) {
                        int size3 = pkgCtx.keyNames0.getSize();
                        int i7 = size3 % 4;
                        int i8 = i7 != 0 ? 4 - i7 : 0;
                        byteBuffer.putInt(i4);
                        byteBuffer.putInt(size3 + i8 + 8);
                        pkgCtx.keyNames0.write(byteBuffer);
                        byteBuffer.put(new byte[i8]);
                        Iterator<Type> it = pkgCtx.pkg.types.values().iterator();
                        while (true) {
                            if (it.hasNext()) {
                                Type next = it.next();
                                D("[%08x]write spec", Integer.valueOf(byteBuffer.position()), next.name);
                                if (next.wPosition == byteBuffer.position()) {
                                    byteBuffer.putInt(1049090);
                                    byteBuffer.putInt((next.specs.length * 4) + 16);
                                    byteBuffer.putInt(next.id);
                                    byteBuffer.putInt(next.specs.length);
                                    for (ResSpec resSpec : next.specs) {
                                        byteBuffer.putInt(resSpec.flags);
                                    }
                                    Iterator<Config> it2 = next.configs.iterator();
                                    while (true) {
                                        if (it2.hasNext()) {
                                            Config next2 = it2.next();
                                            D("[%08x]write config", Integer.valueOf(byteBuffer.position()));
                                            int position3 = byteBuffer.position();
                                            if (next2.wPosition == position3) {
                                                byteBuffer.putInt(3670529);
                                                byteBuffer.putInt(next2.wChunkSize);
                                                byteBuffer.putInt(next.id);
                                                byteBuffer.putInt(next.specs.length);
                                                byteBuffer.putInt(next2.wEntryStart);
                                                D("[%08x]write config ids", Integer.valueOf(byteBuffer.position()));
                                                byteBuffer.put(next2.id);
                                                int length = next2.id.length % 4;
                                                byteBuffer.put(new byte[(length != 0 ? 4 - length : 0)]);
                                                byteBuffer.position(position3 + 56);
                                                D("[%08x]write config entry offsets", Integer.valueOf(byteBuffer.position()));
                                                for (int i9 = 0; i9 < next2.entryCount; i9++) {
                                                    ResEntry resEntry = next2.resources.get(Integer.valueOf(i9));
                                                    if (resEntry == null) {
                                                        byteBuffer.putInt(-1);
                                                    } else {
                                                        byteBuffer.putInt(resEntry.wOffset);
                                                    }
                                                }
                                                if (byteBuffer.position() - position3 == next2.wEntryStart) {
                                                    D("[%08x]write config entrys", Integer.valueOf(byteBuffer.position()));
                                                    for (ResEntry resEntry2 : next2.resources.values()) {
                                                        D("[%08x]ResTable_entry", Integer.valueOf(byteBuffer.position()));
                                                        boolean z = resEntry2.value instanceof BagValue;
                                                        byteBuffer.putShort((short) (z ? 16 : 8));
                                                        int i10 = resEntry2.flag;
                                                        byteBuffer.putShort((short) (z ? i10 | 1 : i10 & -2));
                                                        byteBuffer.putInt(pkgCtx.keyNames.get(resEntry2.spec.name).index);
                                                        if (z) {
                                                            BagValue bagValue = (BagValue) resEntry2.value;
                                                            byteBuffer.putInt(bagValue.parent);
                                                            byteBuffer.putInt(bagValue.map.size());
                                                            for (Map.Entry<Integer, Value> entry : bagValue.map) {
                                                                byteBuffer.putInt(entry.getKey().intValue());
                                                                writeValue(entry.getValue(), byteBuffer);
                                                            }
                                                        } else {
                                                            writeValue((Value) resEntry2.value, byteBuffer);
                                                        }
                                                    }
                                                    i4 = 1835009;
                                                } else {
                                                    throw new RuntimeException();
                                                }
                                            } else {
                                                throw new RuntimeException();
                                            }
                                        }
                                    }
                                } else {
                                    throw new RuntimeException();
                                }
                            }
                        }
                    } else {
                        throw new RuntimeException();
                    }
                } else {
                    throw new RuntimeException();
                }
            } else {
                throw new RuntimeException();
            }
        }
    }

    private void writeValue(Value value, ByteBuffer byteBuffer) {
        byteBuffer.putShort(8);
        byteBuffer.put((byte) 0);
        byteBuffer.put((byte) value.type);
        if (value.type == 3) {
            byteBuffer.putInt(this.strTable.get(value.raw).index);
        } else {
            byteBuffer.putInt(value.data);
        }
    }
}
