package pxb.android.axml;

import java.util.ArrayList;
import java.util.List;

public class Axml extends AxmlVisitor {
    public List<Node> firsts = new ArrayList();
    public List<Ns> nses = new ArrayList();

    public static class Node extends NodeVisitor {
        public List<Attr> attrs = new ArrayList();
        public List<Node> children = new ArrayList();
        public Integer ln;
        public String name;
        public String ns;
        public Text text;

        public static class Attr {
            public String name;
            public String ns;
            public int resourceId;
            public int type;
            public Object value;

            public void accept(NodeVisitor nodeVisitor) {
                nodeVisitor.attr(this.ns, this.name, this.resourceId, this.type, this.value);
            }
        }

        public static class Text {
            public int ln;
            public String text;

            public void accept(NodeVisitor nodeVisitor) {
                nodeVisitor.text(this.ln, this.text);
            }
        }

        public void accept(NodeVisitor nodeVisitor) {
            NodeVisitor child = nodeVisitor.child(this.ns, this.name);
            acceptB(child);
            child.end();
        }

        public void acceptB(NodeVisitor nodeVisitor) {
            Text text2 = this.text;
            if (text2 != null) {
                text2.accept(nodeVisitor);
            }
            for (Attr attr : this.attrs) {
                attr.accept(nodeVisitor);
            }
            Integer num = this.ln;
            if (num != null) {
                nodeVisitor.line(num.intValue());
            }
            for (Node node : this.children) {
                node.accept(nodeVisitor);
            }
        }

        @Override // pxb.android.axml.NodeVisitor
        public void attr(String str, String str2, int i, int i2, Object obj) {
            Attr attr = new Attr();
            attr.name = str2;
            attr.ns = str;
            attr.resourceId = i;
            attr.type = i2;
            attr.value = obj;
            this.attrs.add(attr);
        }

        @Override // pxb.android.axml.NodeVisitor
        public NodeVisitor child(String str, String str2) {
            Node node = new Node();
            node.name = str2;
            node.ns = str;
            this.children.add(node);
            return node;
        }

        @Override // pxb.android.axml.NodeVisitor
        public void line(int i) {
            this.ln = Integer.valueOf(i);
        }

        @Override // pxb.android.axml.NodeVisitor
        public void text(int i, String str) {
            Text text2 = new Text();
            text2.ln = i;
            text2.text = str;
            this.text = text2;
        }
    }

    public static class Ns {
        public int ln;
        public String prefix;
        public String uri;

        public void accept(AxmlVisitor axmlVisitor) {
            axmlVisitor.ns(this.prefix, this.uri, this.ln);
        }
    }

    public void accept(AxmlVisitor axmlVisitor) {
        for (Ns ns : this.nses) {
            ns.accept(axmlVisitor);
        }
        for (Node node : this.firsts) {
            node.accept(axmlVisitor);
        }
    }

    @Override // pxb.android.axml.NodeVisitor
    public NodeVisitor child(String str, String str2) {
        Node node = new Node();
        node.name = str2;
        node.ns = str;
        this.firsts.add(node);
        return node;
    }

    @Override // pxb.android.axml.AxmlVisitor
    public void ns(String str, String str2, int i) {
        Ns ns = new Ns();
        ns.prefix = str;
        ns.uri = str2;
        ns.ln = i;
        this.nses.add(ns);
    }
}
