package rikka.parcelablelist;

import android.os.Binder;
import android.os.IBinder;
import android.os.Parcel;
import android.os.Parcelable;
import android.os.RemoteException;
import android.util.Log;
import java.util.ArrayList;
import java.util.Iterator;
import java.util.List;

public abstract class BaseParcelableListSlice<T> implements Parcelable {
    private static final boolean DEBUG = false;
    private static final int MAX_IPC_SIZE = 65536;
    private static final String TAG = "ParcelableListSlice";
    private final List<T> mList;

    public abstract T readElement(Parcel parcel);

    public abstract void writeElement(T t, Parcel parcel, int i);

    public BaseParcelableListSlice(List<T> list) {
        this.mList = list;
    }

    public final List<T> getList() {
        return this.mList;
    }

    protected BaseParcelableListSlice(Parcel parcel) {
        int readInt = parcel.readInt();
        if (readInt == -1) {
            this.mList = null;
            return;
        }
        ArrayList arrayList = new ArrayList(readInt);
        this.mList = arrayList;
        readSliceFromParcel(arrayList, parcel);
        if (arrayList.size() < readInt) {
            IBinder readStrongBinder = parcel.readStrongBinder();
            do {
                Parcel obtain = Parcel.obtain();
                Parcel obtain2 = Parcel.obtain();
                try {
                    readStrongBinder.transact(1, obtain, obtain2, 0);
                    readSliceFromParcel(this.mList, obtain2);
                    obtain.recycle();
                    obtain2.recycle();
                } catch (RemoteException e) {
                    Log.w(TAG, "Failure retrieving array; only received " + this.mList.size() + " of " + readInt, e);
                    obtain.recycle();
                    obtain2.recycle();
                    return;
                } catch (Throwable th) {
                    obtain.recycle();
                    obtain2.recycle();
                    throw th;
                }
            } while (this.mList.size() < readInt);
        }
    }

    private void readSliceFromParcel(List<T> list, Parcel parcel) {
        int readInt = parcel.readInt();
        for (int i = 0; i < readInt; i++) {
            list.add(readElement(parcel));
        }
    }

    public final void writeToParcel(Parcel parcel, final int i) {
        List<T> list = this.mList;
        if (list == null) {
            parcel.writeInt(-1);
            return;
        }
        parcel.writeInt(list.size());
        final Iterator<T> it = this.mList.iterator();
        writeSliceToParcel(it, parcel, i);
        if (it.hasNext()) {
            parcel.writeStrongBinder(new Binder() {
                /* class rikka.parcelablelist.BaseParcelableListSlice.AnonymousClass1 */

                /* access modifiers changed from: protected */
                @Override // android.os.Binder
                public boolean onTransact(int i, Parcel parcel, Parcel parcel2, int i2) {
                    if (i != 1 || parcel2 == null) {
                        return false;
                    }
                    BaseParcelableListSlice.this.writeSliceToParcel(it, parcel2, i);
                    return true;
                }
            });
        }
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private void writeSliceToParcel(Iterator<T> it, Parcel parcel, int i) {
        int dataPosition = parcel.dataPosition();
        int i2 = 0;
        parcel.writeInt(0);
        while (it.hasNext() && parcel.dataSize() < MAX_IPC_SIZE) {
            writeElement(it.next(), parcel, i);
            i2++;
        }
        int dataPosition2 = parcel.dataPosition();
        parcel.setDataPosition(dataPosition);
        parcel.writeInt(i2);
        parcel.setDataPosition(dataPosition2);
    }
}
