package de.robv.android.xposed;

import android.content.SharedPreferences;
import android.os.Bundle;
import android.os.RemoteException;
import io.github.xposed.xposedservice.IXRemotePreferenceCallback;
import java.util.Iterator;
import java.util.Map;
import java.util.Set;
import java.util.TreeMap;
import java.util.WeakHashMap;
import java.util.concurrent.ConcurrentHashMap;
import org.lsposed.lspd.core.ApplicationServiceClient;

public class XRemotePreference implements SharedPreferences {
    private static final Object CONTENT = new Object();
    IXRemotePreferenceCallback callback;
    final WeakHashMap<SharedPreferences.OnSharedPreferenceChangeListener, Object> mListeners;
    private Map<String, Object> mMap;

    public XRemotePreference(String str) {
        this(str, 0);
    }

    public XRemotePreference(String str, int i) {
        this.mMap = new ConcurrentHashMap();
        this.mListeners = new WeakHashMap<>();
        this.callback = new IXRemotePreferenceCallback.Stub() {
            /* class de.robv.android.xposed.XRemotePreference.AnonymousClass1 */

            @Override // io.github.xposed.xposedservice.IXRemotePreferenceCallback
            public synchronized void onUpdate(Bundle bundle) {
                if (bundle.containsKey("map")) {
                    XRemotePreference.this.mMap = (ConcurrentHashMap) bundle.getSerializable("map");
                }
                if (bundle.containsKey("diff")) {
                    Iterator<String> it = bundle.getStringArrayList("diff").iterator();
                    while (it.hasNext()) {
                        String next = it.next();
                        synchronized (XRemotePreference.this.mListeners) {
                            XRemotePreference.this.mListeners.forEach(new XRemotePreference$1$$ExternalSyntheticLambda0(this, next));
                        }
                    }
                }
            }

            /* access modifiers changed from: package-private */
            /* renamed from: lambda$onUpdate$0$de-robv-android-xposed-XRemotePreference$1  reason: not valid java name */
            public /* synthetic */ void m5lambda$onUpdate$0$derobvandroidxposedXRemotePreference$1(String str, SharedPreferences.OnSharedPreferenceChangeListener onSharedPreferenceChangeListener, Object obj) {
                onSharedPreferenceChangeListener.onSharedPreferenceChanged(XRemotePreference.this, str);
            }
        };
        try {
            this.callback.onUpdate(ApplicationServiceClient.serviceClient.requestRemotePreference(str, i, this.callback.asBinder()));
        } catch (RemoteException e) {
            XposedBridge.log(e);
        }
    }

    @Override // android.content.SharedPreferences
    public Map<String, ?> getAll() {
        return new TreeMap(this.mMap);
    }

    public String getString(String str, String str2) {
        String str3 = (String) this.mMap.getOrDefault(str, str2);
        return str3 != null ? str3 : str2;
    }

    @Override // android.content.SharedPreferences
    public Set<String> getStringSet(String str, Set<String> set) {
        Set<String> set2 = (Set) this.mMap.getOrDefault(str, set);
        return set2 != null ? set2 : set;
    }

    public int getInt(String str, int i) {
        Integer num = (Integer) this.mMap.getOrDefault(str, Integer.valueOf(i));
        return num != null ? num.intValue() : i;
    }

    public long getLong(String str, long j) {
        Long l = (Long) this.mMap.getOrDefault(str, Long.valueOf(j));
        return l != null ? l.longValue() : j;
    }

    public float getFloat(String str, float f) {
        Float f2 = (Float) this.mMap.getOrDefault(str, Float.valueOf(f));
        return f2 != null ? f2.floatValue() : f;
    }

    public boolean getBoolean(String str, boolean z) {
        Boolean bool = (Boolean) this.mMap.getOrDefault(str, Boolean.valueOf(z));
        return bool != null ? bool.booleanValue() : z;
    }

    public boolean contains(String str) {
        return this.mMap.containsKey(str);
    }

    public SharedPreferences.Editor edit() {
        throw new UnsupportedOperationException("Read only implementation");
    }

    public void registerOnSharedPreferenceChangeListener(SharedPreferences.OnSharedPreferenceChangeListener onSharedPreferenceChangeListener) {
        synchronized (this.mListeners) {
            this.mListeners.put(onSharedPreferenceChangeListener, CONTENT);
        }
    }

    public void unregisterOnSharedPreferenceChangeListener(SharedPreferences.OnSharedPreferenceChangeListener onSharedPreferenceChangeListener) {
        synchronized (this.mListeners) {
            this.mListeners.remove(onSharedPreferenceChangeListener);
        }
    }
}
