package org.lsposed.lspd.util;

import android.os.Build;
import android.os.SharedMemory;
import android.system.ErrnoException;
import android.system.Os;
import android.system.OsConstants;
import android.util.Log;
import de.robv.android.xposed.XposedBridge;
import hidden.ByteBufferDexClassLoader;
import java.io.File;
import java.io.IOException;
import java.net.URL;
import java.nio.ByteBuffer;
import java.util.ArrayList;
import java.util.Arrays;
import java.util.Collections;
import java.util.Enumeration;
import java.util.List;
import java.util.jar.JarFile;
import java.util.stream.Stream;
import java.util.zip.ZipEntry;
import sun.misc.CompoundEnumeration;

public final class LspModuleClassLoader extends ByteBufferDexClassLoader {
    private static final List<File> systemNativeLibraryDirs = splitPaths(System.getProperty("java.library.path"));
    private static final String zipSeparator = "!/";
    private final String apk;
    private final List<File> nativeLibraryDirs = new ArrayList();

    private static List<File> splitPaths(String str) {
        ArrayList arrayList = new ArrayList();
        if (str == null) {
            return arrayList;
        }
        for (String str2 : str.split(File.pathSeparator)) {
            arrayList.add(new File(str2));
        }
        return arrayList;
    }

    private LspModuleClassLoader(ByteBuffer[] byteBufferArr, ClassLoader classLoader, String str) {
        super(byteBufferArr, classLoader);
        this.apk = str;
    }

    private LspModuleClassLoader(ByteBuffer[] byteBufferArr, String str, ClassLoader classLoader, String str2) {
        super(byteBufferArr, str, classLoader);
        initNativeLibraryDirs(str);
        this.apk = str2;
    }

    private void initNativeLibraryDirs(String str) {
        this.nativeLibraryDirs.addAll(splitPaths(str));
        this.nativeLibraryDirs.addAll(systemNativeLibraryDirs);
    }

    /* JADX DEBUG: Failed to insert an additional move for type inference into block B:4:0x0009 */
    /* JADX DEBUG: Multi-variable search result rejected for r2v0, resolved type: java.lang.String */
    /* JADX DEBUG: Multi-variable search result rejected for r2v1, resolved type: java.lang.String */
    /* JADX WARN: Multi-variable type inference failed */
    /* JADX WARN: Type inference failed for: r2v5, types: [java.lang.Class<?>, java.lang.Class] */
    /* access modifiers changed from: protected */
    /* JADX WARNING: Can't wrap try/catch for region: R(3:7|8|9) */
    /* JADX WARNING: Code restructure failed: missing block: B:10:0x0017, code lost:
        r3 = move-exception;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:13:0x0020, code lost:
        return getParent().loadClass(r2);
     */
    /* JADX WARNING: Code restructure failed: missing block: B:14:0x0021, code lost:
        throw r3;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:9:0x0016, code lost:
        return findClass(r2);
     */
    /* JADX WARNING: Failed to process nested try/catch */
    /* JADX WARNING: Missing exception handler attribute for start block: B:7:0x0012 */
    @Override // java.lang.ClassLoader
    public Class<?> loadClass(String str, boolean z) throws ClassNotFoundException {
        Class findLoadedClass = findLoadedClass(str);
        if (findLoadedClass != null) {
            return findLoadedClass;
        }
        str = Object.class.getClassLoader().loadClass(str);
        return str;
    }

    public String findLibrary(String str) {
        String mapLibraryName = System.mapLibraryName(str);
        for (File file : this.nativeLibraryDirs) {
            String path = file.getPath();
            if (path.contains(zipSeparator)) {
                String[] split = path.split(zipSeparator, 2);
                try {
                    JarFile jarFile = new JarFile(split[0]);
                    try {
                        String str2 = split[1] + '/' + mapLibraryName;
                        ZipEntry entry = jarFile.getEntry(str2);
                        if (entry == null || entry.getMethod() != 0) {
                            jarFile.close();
                        } else {
                            String str3 = split[0] + zipSeparator + str2;
                            jarFile.close();
                            return str3;
                        }
                    } catch (Throwable th) {
                        th.addSuppressed(th);
                    }
                } catch (IOException e) {
                    Log.e(XposedBridge.TAG, "Can not open " + split[0], e);
                }
            } else if (file.isDirectory()) {
                String path2 = new File(file, mapLibraryName).getPath();
                try {
                    Os.close(Os.open(path2, OsConstants.O_RDONLY, 0));
                    return path2;
                } catch (ErrnoException unused) {
                    continue;
                }
            } else {
                continue;
            }
        }
        return null;
        throw th;
    }

    @Override // hidden.ByteBufferDexClassLoader
    public String getLdLibraryPath() {
        StringBuilder sb = new StringBuilder();
        for (File file : this.nativeLibraryDirs) {
            if (sb.length() > 0) {
                sb.append(':');
            }
            sb.append(file);
        }
        return sb.toString();
    }

    /* access modifiers changed from: protected */
    public URL findResource(String str) {
        try {
            ClassPathURLStreamHandler classPathURLStreamHandler = new ClassPathURLStreamHandler(this.apk);
            URL entryUrlOrNull = classPathURLStreamHandler.getEntryUrlOrNull(str);
            if (entryUrlOrNull == null) {
                classPathURLStreamHandler.finalize();
            }
            return entryUrlOrNull;
        } catch (IOException unused) {
            return null;
        }
    }

    /* access modifiers changed from: protected */
    @Override // dalvik.system.BaseDexClassLoader, java.lang.ClassLoader
    public Enumeration<URL> findResources(String str) {
        ArrayList arrayList = new ArrayList();
        URL findResource = findResource(str);
        if (findResource != null) {
            arrayList.add(findResource);
        }
        return Collections.enumeration(arrayList);
    }

    public URL getResource(String str) {
        URL resource = Object.class.getClassLoader().getResource(str);
        if (resource != null) {
            return resource;
        }
        URL findResource = findResource(str);
        if (findResource != null) {
            return findResource;
        }
        ClassLoader parent = getParent();
        if (parent == null) {
            return null;
        }
        return parent.getResource(str);
    }

    @Override // java.lang.ClassLoader
    public Enumeration<URL> getResources(String str) throws IOException {
        Enumeration[] enumerationArr = new Enumeration[3];
        enumerationArr[0] = Object.class.getClassLoader().getResources(str);
        enumerationArr[1] = findResources(str);
        enumerationArr[2] = getParent() == null ? null : getParent().getResources(str);
        return new CompoundEnumeration(enumerationArr);
    }

    public String toString() {
        if (this.apk == null) {
            return "LspModuleClassLoader[instantiating]";
        }
        return "LspModuleClassLoader[module=" + this.apk + ", " + super.toString() + "]";
    }

    public static ClassLoader loadApk(String str, List<SharedMemory> list, String str2, ClassLoader classLoader) {
        LspModuleClassLoader lspModuleClassLoader;
        ByteBuffer[] byteBufferArr = (ByteBuffer[]) ((Stream) list.stream().parallel()).map(new LspModuleClassLoader$$ExternalSyntheticLambda0()).filter(new LspModuleClassLoader$$ExternalSyntheticLambda1()).toArray(new LspModuleClassLoader$$ExternalSyntheticLambda2());
        if (Build.VERSION.SDK_INT >= 29) {
            lspModuleClassLoader = new LspModuleClassLoader(byteBufferArr, str2, classLoader, str);
        } else {
            lspModuleClassLoader = new LspModuleClassLoader(byteBufferArr, classLoader, str);
            lspModuleClassLoader.initNativeLibraryDirs(str2);
        }
        ((Stream) Arrays.stream(byteBufferArr).parallel()).forEach(new LspModuleClassLoader$$ExternalSyntheticLambda3());
        ((Stream) list.stream().parallel()).forEach(new LspModuleClassLoader$$ExternalSyntheticLambda4());
        return lspModuleClassLoader;
    }

    static /* synthetic */ ByteBuffer lambda$loadApk$0(SharedMemory sharedMemory) {
        try {
            return sharedMemory.mapReadOnly();
        } catch (ErrnoException e) {
            Log.w(XposedBridge.TAG, "Can not map " + sharedMemory, e);
            return null;
        }
    }

    static /* synthetic */ ByteBuffer[] lambda$loadApk$1(int i) {
        return new ByteBuffer[i];
    }
}
